@@ -37,7 +37,7 @@
 #include "wx/mimetype.h"
 #include <wx/sstream.h>
 
-#ifdef __WINDOWS__
+#ifdef _WIN32
     #include "wx/dde.h"
 	#include <windows.h>
 	#include <tlhelp32.h>	//needed to pause process on windows
@@ -45,7 +45,7 @@
 	#include <sys/types.h>	
 	#include <signal.h>	//needed to pause on unix - kill function
 	#include <unistd.h> //needed to separate the process group of make
-#endif // __WINDOWS__
+#endif // _WIN32
 
 // Slightly reworked fix for BUG_2075064 
 #ifdef __WXMAC__
@@ -57,8 +57,6 @@
 #include "MyExternalCmdExecDialog.h"
 #include "hugin/config_defaults.h"
 
-using namespace std;
-
 // ----------------------------------------------------------------------------
 // event tables and other macros for wxWidgets
 // ----------------------------------------------------------------------------
@@ -132,7 +130,6 @@ void MyExecPanel::PauseProcess(bool pause)
 {
 #ifdef __WXMSW__
 	HANDLE hProcessSnapshot = NULL;
-	HANDLE hThreadSnapshot = NULL; 
 	PROCESSENTRY32 pEntry = {0};
 	THREADENTRY32 tEntry = {0};
 
@@ -155,7 +152,7 @@ void MyExecPanel::PauseProcess(bool pause)
 				if((pEntry.th32ProcessID == m_pidLast) || (pEntry.th32ParentProcessID == m_pidLast))
 				{
 					//we take a snapshot of all system threads
-					hThreadSnapshot = CreateToolhelp32Snapshot(TH32CS_SNAPTHREAD, 0); 
+					HANDLE hThreadSnapshot = CreateToolhelp32Snapshot(TH32CS_SNAPTHREAD, 0); 
 					if (hThreadSnapshot == INVALID_HANDLE_VALUE)
 						wxLogError(_("Error pausing process %ld, code 2"),m_pidLast);
 
@@ -244,7 +241,7 @@ int MyExecPanel::ExecWithRedirect(wxString cmd)
     else
     {
         AddAsyncProcess(process);
-#ifndef __WINDOWS__
+#ifndef _WIN32
 		//on linux we put the new process into a separate group, 
 		//so it can be paused with all it's children at the same time
 		setpgid(m_pidLast,m_pidLast);	
