@@ -43,4 +43,19 @@ namespace hugin_utils
         return true;
     }
 
-} // namespace
\ No newline at end of file
+} // namespace
+
+#ifdef __WXMSW__
+  // workaround for wxWidgets bug 14888
+  // see: http://trac.wxwidgets.org/ticket/14888
+  // if this is fixed upstreams this workaround can be removed
+void HuginCHMHelpController::DisplayHelpPage(const wxString& name)
+{
+    // instead of passing filename as dwData to HH_DISPLAY_TOPIC
+    // we pass chmFilename::filename to pszfile 
+    wxString command(GetValidFilename());
+    command.Append(wxT("::"));
+    command.Append(name);
+    CallHtmlHelp(GetParentWindow(), command.t_str(), 0 /* =HH_DISPLAY_TOPIC */);
+};
+#endif
