@@ -65,7 +65,7 @@ str wxQuoteStringInternal(const str & arg, const str & quotechar,
 template <class str>
 str wxQuoteString(const str & arg)
 {
-#ifdef WIN32
+#ifdef _WIN32
     // escape all strange chars with ^
     // is this true for create process?
     return wxQuoteStringInternal(arg, str(wxT("^")), str(wxT("^ \"$|()")));
@@ -81,7 +81,7 @@ str wxQuoteString(const str & arg)
 template <class str>
 str wxQuoteFilename(const str & arg)
 {
-#ifdef WIN32
+#ifdef _WIN32
     str ret;
     // just a guess
     ret = wxQuoteStringInternal(arg, str(wxT("^")), str(wxT("\"")));
@@ -98,4 +98,17 @@ WXIMPEX bool str2double(const wxString& s, double & d);
 
 } // namespace
 
+#ifdef __WXMSW__
+  // workaround for wxWidgets bug 14888
+  // see: http://trac.wxwidgets.org/ticket/14888
+  // which results in crashes when calling help on Win 8/10 64 bit
+  // implement a slightly different version for our needs
+#include "wx/msw/helpchm.h"
+class WXIMPEX HuginCHMHelpController :public wxCHMHelpController
+{
+public:
+    void DisplayHelpPage(const wxString& name);
+};
+#endif
+
 #endif // HUGIN_WXPLATFORM_H
