@@ -59,17 +59,11 @@
 #include "vigra/localminmax.hxx"
 #include "vigra_ext/openmp_vigra.h"
 #include "vigra_ext/Correlation.h"
+#include "vigra_ext/cms.h"
 
 // Celeste header
 #include "Celeste.h"
 
-using namespace std;
-using namespace HuginBase;
-using namespace vigra;
-using namespace vigra_ext;
-using namespace vigra::functor;
-using namespace hugin_utils;
-
 BEGIN_EVENT_TABLE(CPEditorPanel, wxPanel)
     EVT_CPEVENT(CPEditorPanel::OnCPEvent)
     EVT_COMBOBOX(XRCID("cp_editor_left_choice"), CPEditorPanel::OnLeftChoiceChange )
@@ -89,7 +83,10 @@ BEGIN_EVENT_TABLE(CPEditorPanel, wxPanel)
     EVT_BUTTON(XRCID("cp_editor_previous_img"), CPEditorPanel::OnPrevImg)
     EVT_BUTTON(XRCID("cp_editor_next_img"), CPEditorPanel::OnNextImg)
     EVT_BUTTON(XRCID("cp_editor_finetune_button"), CPEditorPanel::OnFineTuneButton)
-    EVT_BUTTON(XRCID("cp_editor_celeste_button"), CPEditorPanel::OnCelesteButton)
+    EVT_BUTTON(XRCID("cp_editor_action_button"), CPEditorPanel::OnActionButton)
+    EVT_MENU(XRCID("cp_menu_create_cp"), CPEditorPanel::OnActionSelectCreate)
+    EVT_MENU(XRCID("cp_menu_celeste"), CPEditorPanel::OnActionSelectCeleste)
+    EVT_MENU(XRCID("cp_menu_clean_cp"), CPEditorPanel::OnActionSelectCleanCP)
 END_EVENT_TABLE()
 
 CPEditorPanel::CPEditorPanel()
@@ -151,10 +148,11 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
     m_cpList->InsertColumn( 6, _("Distance"), wxLIST_FORMAT_RIGHT, 110);
 
     //get saved width
+    wxConfigBase* config = wxConfig::Get();
     for ( int j=0; j < m_cpList->GetColumnCount() ; j++ )
     {
         // -1 is auto
-        int width = wxConfigBase::Get()->Read(wxString::Format( wxT("/CPEditorPanel/ColumnWidth%d"), j ), -1);
+        int width = config->Read(wxString::Format( wxT("/CPEditorPanel/ColumnWidth%d"), j ), -1);
         if(width != -1)
             m_cpList->SetColumnWidth(j, width);
     }
@@ -181,12 +179,13 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
     m_estimateCB = XRCCTRL(*this,"cp_editor_auto_estimate", wxCheckBox);
     DEBUG_ASSERT(m_estimateCB);
 
+    m_actionButton = XRCCTRL(*this, "cp_editor_action_button", wxButton);
+    m_actionButton->Connect(wxEVT_CONTEXT_MENU, wxContextMenuEventHandler(CPEditorPanel::OnActionContextMenu), NULL, this);
+    m_cpActionContextMenu = wxXmlResource::Get()->LoadMenu(wxT("cp_menu_action"));
     // setup scroll window for the controls under the images
     m_cp_ctrls = XRCCTRL(*this, "cp_controls_panel", wxPanel);
     DEBUG_ASSERT(m_cp_ctrls);
 
-    wxConfigBase *config = wxConfigBase::Get();
-
     m_autoAddCB->SetValue(config->Read(wxT("/CPEditorPanel/autoAdd"),0l) != 0 );
     m_fineTuneCB->SetValue(config->Read(wxT("/CPEditorPanel/autoFineTune"),1l) != 0 );
     m_estimateCB->SetValue(config->Read(wxT("/CPEditorPanel/autoEstimate"),1l) != 0 );
@@ -199,7 +198,7 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
     m_fineTuneCB->Disable();
     m_estimateCB->Disable();
     XRCCTRL(*this, "cp_editor_finetune_button", wxButton)->Disable();
-    XRCCTRL(*this, "cp_editor_celeste_button", wxButton)->Disable();
+    m_actionButton->Disable();
     XRCCTRL(*this, "cp_editor_choice_zoom", wxChoice)->Disable();
     XRCCTRL(*this, "cp_editor_previous_img", wxButton)->Disable();
     XRCCTRL(*this, "cp_editor_next_img", wxButton)->Disable();
@@ -212,6 +211,33 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
     OnZoom(dummy);
 
     SetSizer( topsizer );
+    // read last used action setting
+    m_cpActionButtonMode = static_cast<CPTabActionButtonMode>(config->Read(wxT("/CPEditorPanel/ActionMode"), 1l));
+    switch (m_cpActionButtonMode)
+    {
+        case CPTAB_ACTION_CREATE_CP:
+            m_cpActionContextMenu->Check(XRCID("cp_menu_create_cp"), true);
+            {
+                wxCommandEvent e;
+                OnActionSelectCreate(e);
+            };
+            break;
+        case CPTAB_ACTION_CLEAN_CP:
+            m_cpActionContextMenu->Check(XRCID("cp_menu_clean_cp"), true);
+            {
+                wxCommandEvent e;
+                OnActionSelectCleanCP(e);
+            };
+            break;
+        case CPTAB_ACTION_CELESTE:
+        default:
+            m_cpActionContextMenu->Check(XRCID("cp_menu_celeste"), true);
+            {
+                wxCommandEvent e;
+                OnActionSelectCeleste(e);
+            };
+            break;
+    };
 
     return true;
 }
@@ -327,7 +353,7 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
     DEBUG_TRACE("");
     wxString text;
     unsigned int nr = ev.getPointNr();
-    FDiff2D point = ev.getPoint();
+    hugin_utils::FDiff2D point = ev.getPoint();
     bool left (TRUE);
     if (ev.GetEventObject() == m_leftImg) {
         left = true;
@@ -416,7 +442,7 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
         }
     case CPEvent::SCROLLED:
         {
-            wxPoint d(roundi(point.x), roundi(point.y));
+            wxPoint d(hugin_utils::roundi(point.x), hugin_utils::roundi(point.y));
             d = m_rightImg->MaxScrollDelta(d);
             d = m_leftImg->MaxScrollDelta(d);
             m_rightImg->ScrollDelta(d);
@@ -425,7 +451,7 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
         break;
     case CPEvent::DELETE_REGION_SELECTED:
         {
-            UIntSet cpToRemove;
+            HuginBase::UIntSet cpToRemove;
             if(!currentPoints.empty())
             {
                 wxRect rect=ev.getRect();
@@ -437,14 +463,14 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
                         //checking only normal control points
                         if(left)
                         {
-                            if(rect.Contains(roundi(cp.x1),roundi(cp.y1)))
+                            if (rect.Contains(hugin_utils::roundi(cp.x1), hugin_utils::roundi(cp.y1)))
                             {
                                 cpToRemove.insert(localPNr2GlobalPNr(i));
                             };
                         }
                         else
                         {
-                            if(rect.Contains(roundi(cp.x2),roundi(cp.y2)))
+                            if (rect.Contains(hugin_utils::roundi(cp.x2), hugin_utils::roundi(cp.y2)))
                             {
                                 cpToRemove.insert(localPNr2GlobalPNr(i));
                             };
@@ -468,8 +494,8 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
 void CPEditorPanel::CreateNewPoint()
 {
     DEBUG_TRACE("");
-    FDiff2D p1 = m_leftImg->getNewPoint();
-    FDiff2D p2 = m_rightImg->getNewPoint();
+    hugin_utils::FDiff2D p1 = m_leftImg->getNewPoint();
+    hugin_utils::FDiff2D p2 = m_rightImg->getNewPoint();
     HuginBase::ControlPoint point;
     point.image1Nr = m_leftImageNr;
     point.x1 = p1.x;
@@ -617,7 +643,7 @@ unsigned int CPEditorPanel::localPNr2GlobalPNr(unsigned int localNr) const
 }
 
 
-void CPEditorPanel::estimateAndAddOtherPoint(const FDiff2D & p,
+void CPEditorPanel::estimateAndAddOtherPoint(const hugin_utils::FDiff2D & p,
                                              bool left,
                                              CPImageCtrl * thisImg,
                                              unsigned int thisImgNr,
@@ -628,10 +654,10 @@ void CPEditorPanel::estimateAndAddOtherPoint(const FDiff2D & p,
                                              CPCreationState OTHER_POINT,
                                              CPCreationState OTHER_POINT_RETRY)
 {
-    FDiff2D op;
-    op = EstimatePoint(FDiff2D(p.x, p.y), left);
+    hugin_utils::FDiff2D op;
+    op = EstimatePoint(hugin_utils::FDiff2D(p.x, p.y), left);
     // check if point is in image.
-    const SrcPanoImage & pImg = m_pano->getImage(otherImgNr);
+    const HuginBase::SrcPanoImage & pImg = m_pano->getImage(otherImgNr);
     if (op.x < (int) pImg.getSize().width() && op.x >= 0
         && op.y < (int) pImg.getSize().height() && op.y >= 0)
     {
@@ -640,15 +666,15 @@ void CPEditorPanel::estimateAndAddOtherPoint(const FDiff2D & p,
         // hmm probably there should be another separate function for this..
         if (m_fineTuneCB->IsChecked()) {
             MainFrame::Get()->SetStatusText(_("searching similar points..."),0);
-            FDiff2D newPoint = otherImg->getNewPoint();
+            hugin_utils::FDiff2D newPoint = otherImg->getNewPoint();
 
             long templWidth = wxConfigBase::Get()->Read(wxT("/Finetune/TemplateSize"), HUGIN_FT_TEMPLATE_SIZE);
-            const SrcPanoImage & img = m_pano->getImage(thisImgNr);
+            const HuginBase::SrcPanoImage & img = m_pano->getImage(thisImgNr);
             double sAreaPercent = wxConfigBase::Get()->Read(wxT("/Finetune/SearchAreaPercent"),HUGIN_FT_SEARCH_AREA_PERCENT);
             int sWidth = std::min((int)(img.getWidth() * sAreaPercent / 100.0), 500);
-            CorrelationResult corrPoint;
-            double corrOk=false;
-            Diff2D roundp(p.toDiff2D());
+            vigra_ext::CorrelationResult corrPoint;
+            bool corrOk=false;
+            vigra::Diff2D roundp(p.toDiff2D());
             try {
                 corrOk = PointFineTune(thisImgNr,
                                       roundp,
@@ -705,7 +731,7 @@ void CPEditorPanel::estimateAndAddOtherPoint(const FDiff2D & p,
     }
 }
 
-void CPEditorPanel::NewPointChange(FDiff2D p, bool left)
+void CPEditorPanel::NewPointChange(hugin_utils::FDiff2D p, bool left)
 {
     DEBUG_TRACE("");
 
@@ -777,18 +803,18 @@ void CPEditorPanel::NewPointChange(FDiff2D p, bool left)
 
             // TODO: option to ignore the auto fine tune button when multiple images are selected.
             if (m_fineTuneCB->IsChecked() ) {
-                CorrelationResult corrRes;
+                vigra_ext::CorrelationResult corrRes;
 
-                FDiff2D newPoint = otherImg->getNewPoint();
+                hugin_utils::FDiff2D newPoint = otherImg->getNewPoint();
 
                 long templWidth = wxConfigBase::Get()->Read(wxT("/Finetune/TemplateSize"),HUGIN_FT_TEMPLATE_SIZE);
-                const SrcPanoImage & img = m_pano->getImage(thisImgNr);
+                const HuginBase::SrcPanoImage & img = m_pano->getImage(thisImgNr);
                 double sAreaPercent = wxConfigBase::Get()->Read(wxT("/Finetune/SearchAreaPercent"),
                                                                 HUGIN_FT_SEARCH_AREA_PERCENT);
                 int sWidth = std::min((int) (img.getWidth() * sAreaPercent / 100.0), 500);
                 bool corrOk = false;
                 // corr point
-                Diff2D newPoint_round = newPoint.toDiff2D();
+                vigra::Diff2D newPoint_round = newPoint.toDiff2D();
                 try {
                     corrOk = PointFineTune(otherImgNr,
                                            newPoint_round,
@@ -874,10 +900,10 @@ void CPEditorPanel::NewPointChange(FDiff2D p, bool left)
 }
 
 // return a SrcPanoImage so that the given point is in the center
-SrcPanoImage GetImageRotatedTo(const SrcPanoImage& img, const vigra::Diff2D& point, int testWidth, double& neededHFOV)
+HuginBase::SrcPanoImage GetImageRotatedTo(const HuginBase::SrcPanoImage& img, const vigra::Diff2D& point, int testWidth, double& neededHFOV)
 {
     // copy only necessary information into temporary SrcPanoImage
-    SrcPanoImage imgMod;
+    HuginBase::SrcPanoImage imgMod;
     imgMod.setSize(img.getSize());
     imgMod.setProjection(img.getProjection());
     imgMod.setHFOV(img.getHFOV());
@@ -956,9 +982,9 @@ SrcPanoImage GetImageRotatedTo(const SrcPanoImage& img, const vigra::Diff2D& poi
     return imgMod;
 };
 
-CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const vigra::UInt8RGBImage& templImg,
+vigra_ext::CorrelationResult PointFineTuneProjectionAware(const HuginBase::SrcPanoImage& templ, const vigra::UInt8RGBImage& templImg,
     vigra::Diff2D templPos, int templSize,
-    const SrcPanoImage& search, const vigra::UInt8RGBImage& searchImg,
+    const HuginBase::SrcPanoImage& search, const vigra::UInt8RGBImage& searchImg,
     vigra::Diff2D searchPos, int sWidth)
 {
     wxBusyCursor busy;
@@ -977,7 +1003,7 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
         && templ.getHFOV() < 65 && search.getHFOV() < 65
         && fabs(templ.getHFOV() - search.getHFOV()) < 5)
     {
-        CorrelationResult res;
+        vigra_ext::CorrelationResult res;
         if (rotatingFinetune)
         {
             res = vigra_ext::PointFineTuneRotSearch(templImg, templPos, templSize,
@@ -985,8 +1011,8 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
         }
         else
         {
-            res = vigra_ext::PointFineTune(templImg, vigra::RGBToGrayAccessor<RGBValue<UInt8> >(), templPos, templSize,
-                searchImg, vigra::RGBToGrayAccessor<RGBValue<UInt8> >(), searchPos, sWidth);
+            res = vigra_ext::PointFineTune(templImg, vigra::RGBToGrayAccessor<vigra::RGBValue<vigra::UInt8> >(), templPos, templSize,
+                searchImg, vigra::RGBToGrayAccessor<vigra::RGBValue<vigra::UInt8> >(), searchPos, sWidth);
         };
         res.corrPos = templPos;
         return res;
@@ -996,11 +1022,11 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
     // rotate image so that interest point is in the center
     double templHFOV = 0;
     double searchHFOV = 0;
-    SrcPanoImage templMod = GetImageRotatedTo(templ, templPos, templSize, templHFOV);
-    SrcPanoImage searchMod = GetImageRotatedTo(search, searchPos, sWidth + templSize + 5, searchHFOV);
-    CorrelationResult res;
-    res.maxpos = FDiff2D(-1, -1);
-    res.corrPos = FDiff2D(-1, -1);
+    HuginBase::SrcPanoImage templMod = GetImageRotatedTo(templ, templPos, templSize, templHFOV);
+    HuginBase::SrcPanoImage searchMod = GetImageRotatedTo(search, searchPos, sWidth + templSize + 5, searchHFOV);
+    vigra_ext::CorrelationResult res;
+    res.maxpos = hugin_utils::FDiff2D(-1, -1);
+    res.corrPos = hugin_utils::FDiff2D(-1, -1);
     if (templHFOV < 0 || searchHFOV < 0)
     {
         //something went wrong, e.g. image outside of projection circle for fisheye lenses
@@ -1032,7 +1058,7 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
         vigra::Diff2D(0, 0), transform, ptf, false, vigra_ext::INTERP_CUBIC, &dummy);
     // now remap template, we need to remap a little bigger area to have enough information when the template
     // is rotated in PointFineTuneRotSearch
-    Diff2D templPointInt(hugin_utils::roundi(templX), hugin_utils::roundi(templY));
+    vigra::Diff2D templPointInt(hugin_utils::roundi(templX), hugin_utils::roundi(templY));
     vigra::Rect2D rect(templPointInt.x - templSize - 2, templPointInt.y - templSize - 2,
         templPointInt.x + templSize + 2, templPointInt.y + templSize + 2);
     rect &= vigra::Rect2D(opts.getSize());
@@ -1052,7 +1078,7 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
     // we are always using the rotate fine-tune algorithm, because for this case
     // often a rotation is involved
     res = vigra_ext::PointFineTuneRotSearch(templImgMod, templPointInt, templSize,
-        searchImgMod, Diff2D(hugin_utils::roundi(searchX), hugin_utils::roundi(searchY)), sWidth, startAngle, stopAngle, nSteps);
+        searchImgMod, vigra::Diff2D(hugin_utils::roundi(searchX), hugin_utils::roundi(searchY)), sWidth, startAngle, stopAngle, nSteps);
     // we transfer also the new found template position back to the original image
     transform.createTransform(templMod, opts);
     transform.transformImgCoord(res.corrPos.x, res.corrPos.y, templPointInt.x + 0.00001, templPointInt.y + 0.00001);
@@ -1063,12 +1089,12 @@ CorrelationResult PointFineTuneProjectionAware(const SrcPanoImage& templ, const
 };
 
 bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
-                                  const Diff2D & tmplPoint,
+                                  const vigra::Diff2D & tmplPoint,
                                   int templSize,
                                   unsigned int subjImgNr,
-                                  const FDiff2D & o_subjPoint,
+                                  const hugin_utils::FDiff2D & o_subjPoint,
                                   int sWidth,
-                                  CorrelationResult & res)
+                                  vigra_ext::CorrelationResult & res)
 {
     DEBUG_TRACE("tmpl img nr: " << tmplImgNr << " corr src: "
                 << subjImgNr);
@@ -1104,7 +1130,7 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
 #if wxCHECK_VERSION(2, 9, 0)
         wxMessageDialog dlg(this,
             _("No similar point found."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -1114,7 +1140,7 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
         dlg.ShowModal();
 #else
         wxMessageBox(_("An internal transformation went wrong.\nCheck that the point is inside the image."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -1129,7 +1155,7 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
 #if wxCHECK_VERSION(2, 9, 0)
         wxMessageDialog dlg(this,
             _("No similar point found."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -1142,7 +1168,7 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
         wxMessageBox(
             wxString::Format(_("No similar point found. Check the similarity visually.\nCorrelation coefficient (%.3f) is lower than the threshold set in the preferences."),
                              res.maxi),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -1155,7 +1181,7 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
     return true;
 }
 
-void CPEditorPanel::panoramaChanged(Panorama &pano)
+void CPEditorPanel::panoramaChanged(HuginBase::Panorama &pano)
 {
     int nGui = m_cpModeChoice->GetCount();
     int nPano = pano.getNextCPTypeLineNumber()+1;
@@ -1165,7 +1191,7 @@ void CPEditorPanel::panoramaChanged(Panorama &pano)
     {
         m_cpModeChoice->Freeze();
         // remove some items.
-        for (int i = nGui-1; i >=nPano-1; --i) {
+        for (int i = nGui-1; i > nPano-1; --i) {
             m_cpModeChoice->Delete(i);
         }
         if (nPano > 3) {
@@ -1193,7 +1219,7 @@ void CPEditorPanel::panoramaChanged(Panorama &pano)
     DEBUG_TRACE("");
 }
 
-void CPEditorPanel::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
+void CPEditorPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet &changed)
 {
     unsigned int nrImages = pano.getNrOfImages();
     unsigned int nrTabs = m_leftChoice->GetCount();
@@ -1214,7 +1240,7 @@ void CPEditorPanel::panoramaImagesChanged(Panorama &pano, const UIntSet &changed
         m_fineTuneCB->Disable();
         m_estimateCB->Disable();
         XRCCTRL(*this, "cp_editor_finetune_button", wxButton)->Disable();
-        XRCCTRL(*this, "cp_editor_celeste_button", wxButton)->Disable();
+        m_actionButton->Disable();
         XRCCTRL(*this, "cp_editor_choice_zoom", wxChoice)->Disable();
         XRCCTRL(*this, "cp_editor_previous_img", wxButton)->Disable();
         XRCCTRL(*this, "cp_editor_next_img", wxButton)->Disable();
@@ -1229,7 +1255,7 @@ void CPEditorPanel::panoramaImagesChanged(Panorama &pano, const UIntSet &changed
         m_fineTuneCB->Enable();
         m_estimateCB->Enable();
         XRCCTRL(*this, "cp_editor_finetune_button", wxButton)->Enable();
-        XRCCTRL(*this, "cp_editor_celeste_button", wxButton)->Enable();
+        m_actionButton->Enable();
         XRCCTRL(*this, "cp_editor_choice_zoom", wxChoice)->Enable();
         XRCCTRL(*this, "cp_editor_previous_img", wxButton)->Enable();
         XRCCTRL(*this, "cp_editor_next_img", wxButton)->Enable();
@@ -1292,7 +1318,7 @@ void CPEditorPanel::panoramaImagesChanged(Panorama &pano, const UIntSet &changed
 
     // update changed images
     bool update(false);
-    for(UIntSet::const_iterator it = changed.begin(); it != changed.end(); ++it) {
+    for(HuginBase::UIntSet::const_iterator it = changed.begin(); it != changed.end(); ++it) {
         unsigned int imgNr = *it;
         // we only need to update the view if the currently
         // selected images were changed.
@@ -1386,22 +1412,23 @@ void CPEditorPanel::UpdateDisplay(bool newPair)
     mirroredPoints.clear();
 
     // create a list of all control points
-    unsigned int i = 0;
+    HuginBase::CPVector::size_type i = 0;
     m_leftImg->clearCtrlPointList();
     m_rightImg->clearCtrlPointList();
-    for (HuginBase::CPVector::const_iterator it = controlPoints.begin(); it != controlPoints.end(); ++it) {
-        HuginBase::ControlPoint point = *it;
+    for (HuginBase::CPVector::size_type index = 0; index < controlPoints.size(); ++index)
+    {
+        HuginBase::ControlPoint point(controlPoints[index]);
         if ((point.image1Nr == m_leftImageNr) && (point.image2Nr == m_rightImageNr)){
             m_leftImg->setCtrlPoint(point, false);
             m_rightImg->setCtrlPoint(point, true);
-            currentPoints.push_back(make_pair(it - controlPoints.begin(), *it));
+            currentPoints.push_back(std::make_pair(index, point));
             i++;
         } else if ((point.image2Nr == m_leftImageNr) && (point.image1Nr == m_rightImageNr)){
             m_leftImg->setCtrlPoint(point, true);
             m_rightImg->setCtrlPoint(point, false);
             point.mirror();
             mirroredPoints.insert(i);
-            currentPoints.push_back(std::make_pair(it - controlPoints.begin(), point));
+            currentPoints.push_back(std::make_pair(index, point));
             i++;
         }
     }
@@ -1508,7 +1535,7 @@ void CPEditorPanel::OnTextPointChange(wxCommandEvent &e)
 
     // update point state
     double oldValue=cp.x1;
-    bool valid_input=str2double(m_x1Text->GetValue(), cp.x1);
+    bool valid_input=hugin_utils::str2double(m_x1Text->GetValue(), cp.x1);
     if(valid_input)
         valid_input=(cp.x1>=0) && (cp.x1<=m_pano->getSrcImage(cp.image1Nr).getWidth());
     if (!valid_input) {
@@ -1517,7 +1544,7 @@ void CPEditorPanel::OnTextPointChange(wxCommandEvent &e)
         return;
     }
     oldValue=cp.y1;
-    valid_input=str2double(m_y1Text->GetValue(), cp.y1);
+    valid_input = hugin_utils::str2double(m_y1Text->GetValue(), cp.y1);
     if(valid_input)
         valid_input=(cp.y1>=0) && (cp.y1<=m_pano->getSrcImage(cp.image1Nr).getHeight());
     if (!valid_input) {
@@ -1526,7 +1553,7 @@ void CPEditorPanel::OnTextPointChange(wxCommandEvent &e)
         return;
     }
     oldValue=cp.x2;
-    valid_input=str2double(m_x2Text->GetValue(), cp.x2);
+    valid_input = hugin_utils::str2double(m_x2Text->GetValue(), cp.x2);
     if(valid_input)
         valid_input=(cp.x2>=0) && (cp.x2<=m_pano->getSrcImage(cp.image2Nr).getWidth());
     if (!valid_input) {
@@ -1535,7 +1562,7 @@ void CPEditorPanel::OnTextPointChange(wxCommandEvent &e)
         return;
     }
     oldValue=cp.y2;
-    valid_input=str2double(m_y2Text->GetValue(), cp.y2);
+    valid_input = hugin_utils::str2double(m_y2Text->GetValue(), cp.y2);
     if(valid_input)
         valid_input=(cp.y2>=0) && (cp.y2<=m_pano->getSrcImage(cp.image1Nr).getHeight());
     if (!valid_input) {
@@ -1595,6 +1622,20 @@ void CPEditorPanel::OnCPListDeselect(wxListEvent & ev)
 
 void CPEditorPanel::OnZoom(wxCommandEvent & e)
 {
+    int leftX = 0;
+    int leftY = 0;
+    int rightX = 0;
+    int rightY = 0;
+    const wxSize leftSize = m_leftImg->GetClientSize();
+    const wxSize rightSize = m_rightImg->GetClientSize();
+    if (m_leftImg->getScale() > 0)
+    {
+        // remember old scroll position
+        leftX = (m_leftImg->GetScrollPos(wxHORIZONTAL) + leftSize.GetWidth() / 2 )/ m_leftImg->getScale();
+        leftY = (m_leftImg->GetScrollPos(wxVERTICAL) + leftSize.GetHeight() / 2) / m_leftImg->getScale();
+        rightX = (m_rightImg->GetScrollPos(wxHORIZONTAL) + rightSize.GetWidth() / 2) / m_rightImg->getScale();
+        rightY = (m_rightImg->GetScrollPos(wxVERTICAL) + rightSize.GetHeight() / 2) / m_rightImg->getScale();
+    };
     double factor;
     switch (e.GetSelection()) {
     case 0:
@@ -1632,6 +1673,15 @@ void CPEditorPanel::OnZoom(wxCommandEvent & e)
     if (m_selectedPoint < UINT_MAX) {
         SelectLocalPoint(m_selectedPoint);
     }
+    else
+    {
+        if (factor > 0)
+        {
+            // scroll to keep old position in view
+            m_leftImg->Scroll(leftX*factor - leftSize.GetWidth() / 2, leftY*factor - leftSize.GetHeight() / 2);
+            m_rightImg->Scroll(rightX*factor - rightSize.GetWidth() / 2, rightY*factor - rightSize.GetHeight() / 2);
+        };
+    }
 }
 
 void CPEditorPanel::OnKey(wxKeyEvent & e)
@@ -1895,12 +1945,61 @@ void CPEditorPanel::OnFineTuneButton(wxCommandEvent & e)
     }
 }
 
+void CPEditorPanel::OnActionContextMenu(wxContextMenuEvent& e)
+{
+    m_cpActionContextMenu->SetLabel(XRCID("cp_menu_create_cp"), wxString::Format(_("Create cp (Current setting: %s)"), MainFrame::Get()->GetSelectedCPGenerator().c_str()));
+    PopupMenu(m_cpActionContextMenu);
+};
+
+void CPEditorPanel::OnActionButton(wxCommandEvent& e)
+{
+    switch (m_cpActionButtonMode)
+    {
+        case CPTAB_ACTION_CREATE_CP:
+            OnCreateCPButton(e);
+            break;
+        case CPTAB_ACTION_CLEAN_CP:
+            OnCleanCPButton(e);
+            break;
+        case CPTAB_ACTION_CELESTE:
+        default:
+            OnCelesteButton(e);
+            break;
+    };
+};
+
+void CPEditorPanel::OnCreateCPButton(wxCommandEvent& e)
+{
+    if (m_leftImageNr == m_rightImageNr)
+    {
+        // when the same image is selected left and right we are running linefind 
+        // with default parameters
+        CPDetectorSetting linefindSetting;
+#ifdef __WXMSW__
+        linefindSetting.SetProg(wxT("linefind.exe"));
+#else
+        linefindSetting.SetProg(wxT("linefind"));
+#endif
+        linefindSetting.SetArgs(wxT("-o %o %s"));
+        HuginBase::UIntSet imgs;
+        imgs.insert(m_leftImageNr);
+        MainFrame::Get()->RunCPGenerator(linefindSetting, imgs);
+    }
+    else
+    {
+        HuginBase::UIntSet imgs;
+        imgs.insert(m_leftImageNr);
+        imgs.insert(m_rightImageNr);
+        MainFrame::Get()->RunCPGenerator(imgs);
+    };
+};
+
 void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
 {
     if (currentPoints.empty())
     {
         wxMessageBox(_("Cannot run celeste without at least one control point connecting the two images"),_("Error"));
-        cout << "Cannot run celeste without at least one control point connecting the two images" << endl;
+        std::cout << "Cannot run celeste without at least one control point connecting the two images" << std::endl;
     }
     else
     {
@@ -1942,11 +2041,16 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
             in.resize(im8->size());
             vigra::omp::transformImage(srcImageRange(*im8),destImage(in),vigra::functor::Arg1()*vigra::functor::Param(65535/255));
         };
+        // convert to sRGB if icc profile found in file
+        if (!img->iccProfile->empty())
+        { 
+            HuginBase::Color::ApplyICCProfile(in, *(img->iccProfile), TYPE_RGB_16);
+        };
         if (!progress.updateDisplayValue())
         {
             return;
         };
-        UIntSet cloudCP=celeste::getCelesteControlPoints(model,in,currentPoints,radius,threshold,800);
+        HuginBase::UIntSet cloudCP = celeste::getCelesteControlPoints(model, in, currentPoints, radius, threshold, 800);
         in.resize(0,0);
         if (!progress.updateDisplay())
         {
@@ -1961,20 +2065,93 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
         };
 
         progress.updateDisplayValue();
-        wxMessageBox(wxString::Format(_("Removed %d control points"), cloudCP.size()), _("Celeste result"),wxOK|wxICON_INFORMATION,this);
+        wxMessageBox(wxString::Format(_("Removed %lu control points"), static_cast<unsigned long int>(cloudCP.size())), _("Celeste result"), wxOK | wxICON_INFORMATION, this);
         DEBUG_TRACE("Finished running Celeste");
     }
 }
 
-FDiff2D CPEditorPanel::LocalFineTunePoint(unsigned int srcNr,
-                                          const Diff2D & srcPnt,
+void CPEditorPanel::OnCleanCPButton(wxCommandEvent& e)
+{
+    if (currentPoints.size() < 2)
+    {
+        wxBell();
+        return;
+    };
+    // calculate mean and variance only for currently active cp
+    double mean = 0;
+    double var = 0;
+    size_t n = 0;
+    for (HuginBase::CPointVector::const_iterator it = currentPoints.begin(); it != currentPoints.end(); ++it)
+    {
+        n++;
+        double x = it->second.error;
+        double delta = x - mean;
+        mean += delta / n;
+        var += delta*(x - mean);
+    }
+    var = var / (n - 1);
+    const double limit = (sqrt(var) > mean) ? mean : (mean + sqrt(var));
+    HuginBase::UIntSet removedCPs;
+    for (HuginBase::CPointVector::const_iterator it = currentPoints.begin(); it != currentPoints.end(); ++it)
+    {
+        if (it->second.error > limit)
+        {
+            removedCPs.insert(it->first);
+        };
+    };
+    if (!removedCPs.empty())
+    {
+        wxMessageBox(wxString::Format(_("Removed %lu control points"), (unsigned long int)removedCPs.size()), _("Cleaning"), wxOK | wxICON_INFORMATION, this);
+        PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::RemoveCtrlPointsCmd(*m_pano, removedCPs));
+    }
+    else
+    {
+        wxBell();
+    }
+};
+
+void CPEditorPanel::OnActionSelectCreate(wxCommandEvent& e)
+{
+    m_cpActionButtonMode = CPTAB_ACTION_CREATE_CP;
+    wxString s(_("Create cp"));
+    s.Append(wxT("\u25bc"));
+    m_actionButton->SetLabel(s);
+    m_actionButton->SetToolTip(_("Create control points for image pair with currently selected control point detector on photos tab."));
+    Layout();
+    wxConfig::Get()->Write(wxT("/CPEditorPanel/ActionMode"), static_cast<long>(m_cpActionButtonMode));
+};
+
+void CPEditorPanel::OnActionSelectCeleste(wxCommandEvent& e)
+{
+    m_cpActionButtonMode = CPTAB_ACTION_CELESTE;
+    wxString s(_("Celeste"));
+    s.Append(wxT("\u25bc"));
+    m_actionButton->SetLabel(s);
+    m_actionButton->SetToolTip(_("Tries to remove control points from clouds"));
+    Layout();
+    wxConfig::Get()->Write(wxT("/CPEditorPanel/ActionMode"), static_cast<long>(m_cpActionButtonMode));
+};
+
+void CPEditorPanel::OnActionSelectCleanCP(wxCommandEvent& e)
+{
+    m_cpActionButtonMode = CPTAB_ACTION_CLEAN_CP;
+    wxString s(_("Clean cp"));
+    s.Append(wxT("\u25bc"));
+    m_actionButton->SetLabel(s);
+    m_actionButton->SetToolTip(_("Remove outlying control points by statistical method"));
+    Layout();
+    wxConfig::Get()->Write(wxT("/CPEditorPanel/ActionMode"), static_cast<long>(m_cpActionButtonMode));
+};
+
+hugin_utils::FDiff2D CPEditorPanel::LocalFineTunePoint(unsigned int srcNr,
+                                          const vigra::Diff2D & srcPnt,
                                           hugin_utils::FDiff2D & movedSrcPnt,
                                           unsigned int moveNr,
-                                          const FDiff2D & movePnt)
+                                          const hugin_utils::FDiff2D & movePnt)
 {
     long templWidth = wxConfigBase::Get()->Read(wxT("/Finetune/TemplateSize"),HUGIN_FT_TEMPLATE_SIZE);
     long sWidth = templWidth + wxConfigBase::Get()->Read(wxT("/Finetune/LocalSearchWidth"),HUGIN_FT_LOCAL_SEARCH_WIDTH);
-    CorrelationResult result;
+    vigra_ext::CorrelationResult result;
     PointFineTune(srcNr,
                   srcPnt,
                   templWidth,
@@ -1985,7 +2162,7 @@ FDiff2D CPEditorPanel::LocalFineTunePoint(unsigned int srcNr,
     movedSrcPnt = result.corrPos;
     if (result.corrPos.x < 0 || result.corrPos.y < 0 || result.maxpos.x < 0 || result.maxpos.y < 0)
     {
-        return FDiff2D(-1, -1);
+        return hugin_utils::FDiff2D(-1, -1);
     }
     return result.maxpos;
 }
@@ -2000,17 +2177,17 @@ void CPEditorPanel::FineTuneSelectedPoint(bool left)
 
     unsigned int srcNr = cp.image1Nr;
     unsigned int moveNr = cp.image2Nr;
-    Diff2D srcPnt(roundi(cp.x1), roundi(cp.y1));
-    Diff2D movePnt(roundi(cp.x2), roundi(cp.y2));
+    vigra::Diff2D srcPnt(hugin_utils::roundi(cp.x1), hugin_utils::roundi(cp.y1));
+    vigra::Diff2D movePnt(hugin_utils::roundi(cp.x2), hugin_utils::roundi(cp.y2));
     if (left) {
         srcNr = cp.image2Nr;
         moveNr = cp.image1Nr;
-        srcPnt = Diff2D(roundi(cp.x2), roundi(cp.y2));
-        movePnt = Diff2D(roundi(cp.x1), roundi(cp.y1));
+        srcPnt = vigra::Diff2D(hugin_utils::roundi(cp.x2), hugin_utils::roundi(cp.y2));
+        movePnt = vigra::Diff2D(hugin_utils::roundi(cp.x1), hugin_utils::roundi(cp.y1));
     }
 
-    FDiff2D movedSrcPnt;
-    FDiff2D result = LocalFineTunePoint(srcNr, srcPnt, movedSrcPnt, moveNr, movePnt);
+    hugin_utils::FDiff2D movedSrcPnt;
+    hugin_utils::FDiff2D result = LocalFineTunePoint(srcNr, srcPnt, movedSrcPnt, moveNr, movePnt);
 
     if (result.x < 0 || result.y < 0)
     {
@@ -2049,13 +2226,13 @@ void CPEditorPanel::FineTuneNewPoint(bool left)
         return;
     }
 
-    FDiff2D leftP = m_leftImg->getNewPoint();
-    FDiff2D rightP = m_rightImg->getNewPoint();
+    hugin_utils::FDiff2D leftP = m_leftImg->getNewPoint();
+    hugin_utils::FDiff2D rightP = m_rightImg->getNewPoint();
 
     unsigned int srcNr = m_leftImageNr;
-    Diff2D srcPnt(leftP.toDiff2D());
+    vigra::Diff2D srcPnt(leftP.toDiff2D());
     unsigned int moveNr = m_rightImageNr;
-    Diff2D movePnt(rightP.toDiff2D());
+    vigra::Diff2D movePnt(rightP.toDiff2D());
     if (left) {
         srcNr = m_rightImageNr;
         srcPnt = rightP.toDiff2D();
@@ -2063,8 +2240,8 @@ void CPEditorPanel::FineTuneNewPoint(bool left)
         movePnt = leftP.toDiff2D();
     }
 
-    FDiff2D movedSrcPnt;
-    FDiff2D result = LocalFineTunePoint(srcNr, srcPnt, movedSrcPnt, moveNr, movePnt);
+    hugin_utils::FDiff2D movedSrcPnt;
+    hugin_utils::FDiff2D result = LocalFineTunePoint(srcNr, srcPnt, movedSrcPnt, moveNr, movePnt);
 
     if (result.x < 0 || result.y < 0)
     {
@@ -2085,7 +2262,7 @@ void CPEditorPanel::FineTuneNewPoint(bool left)
     }
 }
 
-FDiff2D CPEditorPanel::EstimatePoint(const FDiff2D & p, bool left)
+hugin_utils::FDiff2D CPEditorPanel::EstimatePoint(const hugin_utils::FDiff2D & p, bool left)
 {
     size_t nrNormalCp = 0;
     for (HuginBase::CPointVector::const_iterator it = currentPoints.begin(); it != currentPoints.end(); ++it)
@@ -2098,18 +2275,18 @@ FDiff2D CPEditorPanel::EstimatePoint(const FDiff2D & p, bool left)
     if (nrNormalCp==0)
     {
         DEBUG_WARN("Cannot estimate position without at least one point");
-        return FDiff2D(0,0);
+        return hugin_utils::FDiff2D(0, 0);
     }
 
     // get copy of SrcPanoImage and reset position
-    SrcPanoImage leftImg = m_pano->getSrcImage(left ? m_leftImageNr : m_rightImageNr);
+    HuginBase::SrcPanoImage leftImg = m_pano->getSrcImage(left ? m_leftImageNr : m_rightImageNr);
     leftImg.setYaw(0);
     leftImg.setPitch(0);
     leftImg.setRoll(0);
     leftImg.setX(0);
     leftImg.setY(0);
     leftImg.setZ(0);
-    SrcPanoImage rightImg = m_pano->getSrcImage(left ? m_rightImageNr : m_leftImageNr);
+    HuginBase::SrcPanoImage rightImg = m_pano->getSrcImage(left ? m_rightImageNr : m_leftImageNr);
     rightImg.setYaw(0);
     rightImg.setPitch(0);
     rightImg.setRoll(0);
@@ -2117,7 +2294,7 @@ FDiff2D CPEditorPanel::EstimatePoint(const FDiff2D & p, bool left)
     rightImg.setY(0);
     rightImg.setZ(0);
     // generate a temporary pano
-    Panorama optPano;
+    HuginBase::Panorama optPano;
     optPano.addImage(leftImg);
     optPano.addImage(rightImg);
     // construct OptimizeVector
@@ -2154,7 +2331,7 @@ FDiff2D CPEditorPanel::EstimatePoint(const FDiff2D & p, bool left)
     transformBackward.createInvTransform(optPano.getImage(0), optPano.getOptions());
     HuginBase::PTools::Transform transformForward;
     transformForward.createTransform(optPano.getImage(1), optPano.getOptions());
-    FDiff2D t;
+    hugin_utils::FDiff2D t;
     if (transformBackward.transformImgCoord(t, p))
     {
         if (transformForward.transformImgCoord(t, t))
@@ -2169,7 +2346,7 @@ FDiff2D CPEditorPanel::EstimatePoint(const FDiff2D & p, bool left)
         };
     };
     wxBell();
-    return FDiff2D(0, 0);
+    return hugin_utils::FDiff2D(0, 0);
 }
 
 void CPEditorPanel::OnColumnWidthChange( wxListEvent & e )
