@@ -41,10 +41,6 @@
 #include "hugin_base/panotools/PanoToolsUtils.h"
 #include "algorithms/basic/CalculateCPStatistics.h"
 
-using namespace HuginBase;
-using namespace std;
-using namespace hugin_utils;
-
 BEGIN_EVENT_TABLE(CPListCtrl, wxListCtrl)
     EVT_CHAR(CPListCtrl::OnChar)
     EVT_LIST_ITEM_SELECTED(wxID_ANY, CPListCtrl::OnCPListSelectionChanged)
@@ -116,7 +112,7 @@ bool CPListCtrl::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos,
     return true;
 };
 
-void CPListCtrl::Init(Panorama* pano)
+void CPListCtrl::Init(HuginBase::Panorama* pano)
 {
     m_pano = pano;
     m_pano->addObserver(this);
@@ -192,7 +188,7 @@ void CPListCtrl::UpdateInternalCPList()
     {
         m_internalCPList[i].globalIndex = i;
         const HuginBase::ControlPoint& cp = cps[i];
-        string pairId = makePairId(cp.image1Nr, cp.image2Nr);
+        std::string pairId = makePairId(cp.image1Nr, cp.image2Nr);
         std::map<std::string, int>::iterator it = m_localIds.find(pairId);
         if (it != m_localIds.end())
         {
@@ -235,7 +231,7 @@ CompareStruct(localNumber)
 #define CompareStruct(VAR)\
 struct Compare##VAR\
 {\
-    Compare##VAR(const HuginBase::CPVector& cps) : m_cps(cps) {};\
+    explicit Compare##VAR(const HuginBase::CPVector& cps) : m_cps(cps) {};\
     bool operator()(const CPListItem& item1, const CPListItem& item2)\
     {\
          return m_cps[item1.globalIndex].VAR < m_cps[item2.globalIndex].VAR; \
@@ -252,7 +248,7 @@ CompareStruct(error)
 #define CompareStruct(VAR)\
 struct Compare##VAR##Greater\
 {\
-    Compare##VAR##Greater(const HuginBase::CPVector& cps) : m_cps(cps) {};\
+    explicit Compare##VAR##Greater(const HuginBase::CPVector& cps) : m_cps(cps) {};\
     bool operator()(const CPListItem& item1, const CPListItem& item2)\
     {\
          return m_cps[item1.globalIndex].VAR > m_cps[item2.globalIndex].VAR; \
@@ -385,7 +381,7 @@ void CPListCtrl::DeleteSelected()
         return;
     };
 
-    UIntSet selected;
+    HuginBase::UIntSet selected;
     long item = GetFirstSelected();
     long newSelection = -1;
     if (m_internalCPList.size() - nSelected > 0)
@@ -489,7 +485,7 @@ BEGIN_EVENT_TABLE(CPListFrame, wxFrame)
     EVT_BUTTON(XRCID("cp_list_select"), CPListFrame::OnSelectButton)
 END_EVENT_TABLE()
 
-CPListFrame::CPListFrame(wxFrame* parent, Panorama& pano) : m_pano(pano)
+CPListFrame::CPListFrame(wxFrame* parent, HuginBase::Panorama& pano) : m_pano(pano)
 {
     DEBUG_TRACE("");
     bool ok = wxXmlResource::Get()->LoadFrame(this, parent, wxT("cp_list_frame"));
@@ -538,7 +534,6 @@ void CPListFrame::OnDeleteButton(wxCommandEvent & e)
 void CPListFrame::OnSelectButton(wxCommandEvent & e)
 {
     // calculate the mean error and the standard deviation
-    const HuginBase::CPVector & cps = m_pano.getCtrlPoints();
     HuginBase::PTools::calcCtrlPointErrors(m_pano);
     double min, max, mean, var;
     HuginBase::CalculateCPStatisticsError::calcCtrlPntsErrorStats(m_pano, min, max, mean, var);
@@ -551,13 +546,13 @@ void CPListFrame::OnSelectButton(wxCommandEvent & e)
     do
     {
         t = wxGetTextFromUser(_("Enter minimum control point error.\nAll points with a higher error will be selected"), _("Select Control Points"),
-            doubleTowxString(threshold, 2));
+            hugin_utils::doubleTowxString(threshold, 2));
         if (t == wxEmptyString) {
             // do not select anything
             return;
         }
     }
-    while (!str2double(t, threshold));
+    while (!hugin_utils::str2double(t, threshold));
 
     m_list->SelectDistanceThreshold(threshold);
 };
