@@ -15,8 +15,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,9 +25,9 @@
 #include "panoinc.h"
 
 #include "DragTool.h"
-#include "CommandHistory.h"
-#include "PT/PanoCommand.h"
-#include "PT/ImageGraph.h"
+#include "base_wx/CommandHistory.h"
+#include "base_wx/PanoCommand.h"
+#include "algorithms/optimizer/ImageGraph.h"
 
 #include <math.h>
 #include <wx/platform.h>
@@ -269,10 +269,9 @@ void DragTool::MouseButtonEvent(wxMouseEvent &e)
                 } else {
 
 
-                    PT::CPGraph graph;
-                    PT::createCPGraph(*helper->GetPanoramaPtr(), graph);
-                    PT::CPComponents components;
-                    unsigned int n = PT::findCPComponents(graph, components);
+                    HuginGraph::ImageGraph graph(*helper->GetPanoramaPtr());
+                    HuginGraph::ImageGraph::Components components=graph.GetComponents();
+                    const size_t n = components.size();
                     // If there is only component, we can drag everything. Otherwise the
                     // component we want is the lowest numbered image under the mouse.
                     if (n == 1)
@@ -298,8 +297,8 @@ void DragTool::MouseButtonEvent(wxMouseEvent &e)
                         
                         // Find the component containing the topmost image under mouse
                         unsigned int img = *helper->GetImageNumbersUnderMouse().begin();
-                        for (unsigned int component_index = 0;
-                             component_index < components.size(); component_index ++)
+                        for (size_t component_index = 0;
+                             component_index < n; component_index ++)
                         {
                             if (components[component_index].count(img))
                             {
@@ -348,8 +347,8 @@ void DragTool::MouseButtonEvent(wxMouseEvent &e)
 	        src_images[count].setRoll(nroll);
 	        count++;
         }
-        GlobalCmdHist::getInstance().addCommand(
-            new PT::UpdateSrcImagesCmd(*helper->GetPanoramaPtr(),
+        PanoCommand::GlobalCmdHist::getInstance().addCommand(
+            new PanoCommand::UpdateSrcImagesCmd(*helper->GetPanoramaPtr(),
                                             draging_images,
                                             src_images)
             );
