@@ -73,10 +73,6 @@
 #include "PluginItems.h"
 #endif
 
-using namespace HuginBase;
-using namespace std;
-using namespace hugin_utils;
-
 #ifdef __MINGW32__
 // fixes for mingw compilation...
 #undef FindWindow
@@ -248,6 +244,8 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_MENU(XRCID("ID_SHOW_PANEL_OPTIMIZER"), MainFrame::OnShowPanel)
     EVT_MENU(XRCID("ID_SHOW_PANEL_OPTIMIZER_PHOTOMETRIC"), MainFrame::OnShowPanel)
     EVT_MENU(XRCID("ID_SHOW_PANEL_PANORAMA"), MainFrame::OnShowPanel)
+    EVT_MENU(XRCID("action_stitch"), MainFrame::OnDoStitch)
+    EVT_MENU(XRCID("action_stitch_userdefined"), MainFrame::OnUserDefinedStitch)
     EVT_MENU(XRCID("action_add_images"),  MainFrame::OnAddImages)
     EVT_BUTTON(XRCID("action_add_images"),  MainFrame::OnAddImages)
     EVT_MENU(XRCID("action_add_time_images"),  MainFrame::OnAddTimeImages)
@@ -262,7 +260,7 @@ END_EVENT_TABLE()
 //wxBitmap *p_img = (wxBitmap *) NULL;
 //WX_DEFINE_ARRAY()
 
-MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
+MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     : cp_frame(0), pano(pano)
 {
     preview_frame = 0;
@@ -566,7 +564,7 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
 #endif
     //reload gui level
     long guiLevel=config->Read(wxT("/GuiLevel"),(long)0);
-    guiLevel=max<long>(0,min<long>(2,guiLevel));
+    guiLevel = std::max<long>(0, std::min<long>(2, guiLevel));
     if(guiLevel==GUI_SIMPLE && disableOpenGL)
     {
         guiLevel=GUI_ADVANCED;
@@ -690,9 +688,9 @@ void MainFrame::OnUserQuit(wxCommandEvent & e)
 bool MainFrame::CloseProject(bool cancelable)
 {
     if (pano.isDirty()) {
-        wxMessageDialog message(wxTheApp->GetTopWindow(),
+        wxMessageDialog message(wxGetActiveWindow(),
                                 _("Save changes to the panorama before closing?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                 _("Hugin"),
 #else
                                 wxT(""),
@@ -763,7 +761,6 @@ void MainFrame::OnExit(wxCloseEvent & e)
 void MainFrame::OnSaveProject(wxCommandEvent & e)
 {
     DEBUG_TRACE("");
-    bool savedProjectFile=false;
     try {
     wxFileName scriptName = m_filename;
     if (m_filename == wxT("")) {
@@ -771,7 +768,7 @@ void MainFrame::OnSaveProject(wxCommandEvent & e)
         scriptName = m_filename;
     } else {
         // the project file is just a PTOptimizer script...
-        std::string path = getPathPrefix(std::string(scriptName.GetFullPath().mb_str(HUGIN_CONV_FILENAME)));
+        std::string path = hugin_utils::getPathPrefix(std::string(scriptName.GetFullPath().mb_str(HUGIN_CONV_FILENAME)));
         DEBUG_DEBUG("stripping " << path << " from image filenames");
         std::ofstream script(scriptName.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
         script.exceptions ( std::ofstream::eofbit | std::ofstream::failbit | std::ofstream::badbit );
@@ -781,7 +778,6 @@ void MainFrame::OnSaveProject(wxCommandEvent & e)
         }
         pano.printPanoramaScript(script, pano.getOptimizeVector(), pano.getOptions(), all, false, path);
         script.close();
-        savedProjectFile=true;
 
         SetStatusText(wxString::Format(_("saved project %s"), m_filename.c_str()),0);
         if(m_guiLevel==GUI_SIMPLE)
@@ -818,7 +814,7 @@ void MainFrame::OnSaveProjectAs(wxCommandEvent & e)
         scriptName=m_filename;
     };
     scriptName.Normalize();
-    wxFileDialog dlg(wxTheApp->GetTopWindow(),
+    wxFileDialog dlg(wxGetActiveWindow(),
                      _("Save project file"),
                      scriptName.GetPath(), scriptName.GetFullName(),
                      _("Project files (*.pto)|*.pto|All files (*)|*"),
@@ -852,7 +848,7 @@ void MainFrame::OnSavePTStitcherAs(wxCommandEvent & e)
     }
     wxFileName scriptNameFN(scriptName);
     wxString fn = scriptNameFN.GetName() + wxT(".txt");
-    wxFileDialog dlg(wxTheApp->GetTopWindow(),
+    wxFileDialog dlg(wxGetActiveWindow(),
                      _("Save PTmender script file"),
                      wxConfigBase::Get()->Read(wxT("/actualPath"),wxT("")), fn,
                      _("PTmender files (*.txt)|*.txt"),
@@ -954,7 +950,7 @@ void MainFrame::OnLoadProject(wxCommandEvent & e)
         wxConfigBase* config = wxConfigBase::Get();
 
         wxString defaultdir = config->Read(wxT("/actualPath"),wxT(""));
-        wxFileDialog dlg(wxTheApp->GetTopWindow(),
+        wxFileDialog dlg(wxGetActiveWindow(),
                          _("Open project file"),
                          defaultdir, wxT(""),
                          _("Project files (*.pto)|*.pto|All files (*)|*"),
@@ -1024,8 +1020,8 @@ void MainFrame::OnAddImages( wxCommandEvent& event )
 {
     DEBUG_TRACE("");
     PanoOperation::AddImageOperation addImage;
-    UIntSet images;
-    PanoCommand::PanoCommand* cmd=addImage.GetCommand(wxTheApp->GetTopWindow(), pano, images, m_guiLevel);
+    HuginBase::UIntSet images;
+    PanoCommand::PanoCommand* cmd = addImage.GetCommand(wxGetActiveWindow(), pano, images, m_guiLevel);
     if(cmd!=NULL)
     {
         PanoCommand::GlobalCmdHist::getInstance().addCommand(cmd);
@@ -1075,8 +1071,8 @@ void MainFrame::AddImages(wxArrayString& filenameArray)
 void MainFrame::OnAddTimeImages( wxCommandEvent& event )
 {
     PanoOperation::AddImagesSeriesOperation imageSeriesOp;
-    UIntSet images;
-    PanoCommand::PanoCommand* cmd=imageSeriesOp.GetCommand(wxTheApp->GetTopWindow(), pano, images, m_guiLevel);
+    HuginBase::UIntSet images;
+    PanoCommand::PanoCommand* cmd = imageSeriesOp.GetCommand(wxGetActiveWindow(), pano, images, m_guiLevel);
     if(cmd!=NULL)
     {
         PanoCommand::GlobalCmdHist::getInstance().addCommand(cmd);
@@ -1137,7 +1133,7 @@ void MainFrame::OnShowPanel(wxCommandEvent & e)
 
 void MainFrame::OnAbout(wxCommandEvent & e)
 {
-    AboutDialog dlg(wxTheApp->GetTopWindow());
+    AboutDialog dlg(wxGetActiveWindow());
     dlg.ShowModal();
 }
 
@@ -1175,7 +1171,7 @@ void MainFrame::OnAbout(wxCommandEvent & e)
 
 void MainFrame::OnHelp(wxCommandEvent & e)
 {
-    DisplayHelp(wxT("/Hugin.html"));
+    DisplayHelp();
 }
 
 void MainFrame::OnKeyboardHelp(wxCommandEvent & e)
@@ -1198,15 +1194,26 @@ void MainFrame::DisplayHelp(wxString section)
     // make it look nicer with some CSS styling
 
     // section is the HTML document to be displayed, from inside the data folder
-    if(section==wxT("")){
-        section = wxT("/Hugin.html");
-    }
 
     DEBUG_TRACE("");
 
 #ifdef __WXMSW__
-    GetHelpController().DisplaySection(section);
+    if (section.IsEmpty())
+    {
+        // wxWidgets 3.x has a bug, that prevents DisplaySection to work on Win8/10 64 bit
+        // see: http://trac.wxwidgets.org/ticket/14888
+        // so using DisplayContents() and our own implementation of HuginCHMHelpController
+        GetHelpController().DisplayContents();
+    }
+    else
+    {
+        GetHelpController().DisplayHelpPage(section);
+    };
 #else
+    if (section.IsEmpty())
+    {
+        section = wxT("/Hugin.html");
+    }
 #if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
     // On Mac, xrc/data/help_LOCALE should be in the bundle as LOCALE.lproj/help
     // which we can rely on the operating sytem to pick the right locale's.
@@ -1261,7 +1268,7 @@ void MainFrame::OnTipOfDay(wxCommandEvent& WXUNUSED(e))
 
     DEBUG_INFO("Reading tips from " << strFile.mb_str(wxConvLocal));
     wxTipProvider *tipProvider = new LocalizedFileTipProvider(strFile, nValue);
-    bShowAtStartup = wxShowTip(wxTheApp->GetTopWindow(), tipProvider,(nValue ? true:false));
+    bShowAtStartup = wxShowTip(wxGetActiveWindow(), tipProvider, (nValue ? true : false));
 
     //store startup preferences
     nValue = (bShowAtStartup ? tipProvider->GetCurrentTip() : 0);
@@ -1274,7 +1281,7 @@ void MainFrame::OnTipOfDay(wxCommandEvent& WXUNUSED(e))
 void MainFrame::OnShowPrefs(wxCommandEvent & e)
 {
     DEBUG_TRACE("");
-    PreferencesDialog pref_dlg(wxTheApp->GetTopWindow());
+    PreferencesDialog pref_dlg(wxGetActiveWindow());
     pref_dlg.ShowModal();
     //update image cache size
     wxConfigBase* cfg=wxConfigBase::Get();
@@ -1388,13 +1395,18 @@ void MainFrame::OnDoStitch(wxCommandEvent & e)
     pano_panel->GetEventHandler()->AddPendingEvent(cmdEvt);
 }
 
+void MainFrame::OnUserDefinedStitch(wxCommandEvent & e)
+{
+    pano_panel->DoUserDefinedStitch();
+}
+
 void MainFrame::OnMergeProject(wxCommandEvent & e)
 {
     // get the global config object
     wxConfigBase* config = wxConfigBase::Get();
 
     wxString defaultdir = config->Read(wxT("/actualPath"),wxT(""));
-    wxFileDialog dlg(wxTheApp->GetTopWindow(),
+    wxFileDialog dlg(wxGetActiveWindow(),
                      _("Open project file"),
                      defaultdir, wxT(""),
                      _("Project files (*.pto)|*.pto|All files (*)|*"),
@@ -1413,7 +1425,7 @@ void MainFrame::OnMergeProject(wxCommandEvent & e)
             int ptoversion=0;
             if (newPano.loadPTScript(in, ptoversion, (const char *)path.mb_str(HUGIN_CONV_FILENAME)))
             {
-                Panorama new_pano;
+                HuginBase::Panorama new_pano;
                 new_pano.setMemento(newPano);
                 PanoCommand::GlobalCmdHist::getInstance().addCommand(
                     new PanoCommand::MergePanoCmd(pano, new_pano)
@@ -1439,7 +1451,7 @@ void MainFrame::OnApplyTemplate(wxCommandEvent & e)
     // get the global config object
     wxConfigBase* config = wxConfigBase::Get();
 
-    wxFileDialog dlg(wxTheApp->GetTopWindow(),
+    wxFileDialog dlg(wxGetActiveWindow(),
                      _("Choose template project"),
                      config->Read(wxT("/templatePath"),wxT("")), wxT(""),
                      _("Project files (*.pto)|*.pto|All files (*)|*"),
@@ -1516,7 +1528,7 @@ void MainFrame::OnFineTuneAll(wxCommandEvent & e)
     const long sWidth = templWidth + cfg->Read(wxT("/Finetune/LocalSearchWidth"), HUGIN_FT_LOCAL_SEARCH_WIDTH);
 
     {
-    ProgressReporterDialog progress(unoptimized.size(), _("Fine-tuning all points"), _("Fine-tuning"), wxTheApp->GetTopWindow());
+        ProgressReporterDialog progress(unoptimized.size(), _("Fine-tuning all points"), _("Fine-tuning"), wxGetActiveWindow());
 
     ImageCache & imgCache = ImageCache::getInstance();
 
@@ -1545,8 +1557,8 @@ void MainFrame::OnFineTuneAll(wxCommandEvent & e)
                         pano.getImage(cps[*it].image1Nr).getFilename())->get8BitImage();
 
                     vigra_ext::CorrelationResult res;
-                    vigra::Diff2D roundP1(roundi(cps[*it].x1), roundi(cps[*it].y1));
-                    vigra::Diff2D roundP2(roundi(cps[*it].x2), roundi(cps[*it].y2));
+                    vigra::Diff2D roundP1(hugin_utils::roundi(cps[*it].x1), hugin_utils::roundi(cps[*it].y1));
+                    vigra::Diff2D roundP2(hugin_utils::roundi(cps[*it].x2), hugin_utils::roundi(cps[*it].y2));
 
                     res = PointFineTuneProjectionAware(pano.getImage(cps[*it].image1Nr), *templImg, roundP1, templWidth,
                         pano.getImage(cps[*it].image2Nr), *searchImg, roundP2, sWidth);
@@ -1600,7 +1612,7 @@ void MainFrame::OnRemoveCPinMasks(wxCommandEvent & e)
 {
     if(pano.getCtrlPoints().size()<2)
         return;
-    UIntSet cps=getCPinMasks(pano);
+    HuginBase::UIntSet cps=getCPinMasks(pano);
     if(cps.size()>0)
     {
         PanoCommand::GlobalCmdHist::getInstance().addCommand(
@@ -1615,7 +1627,7 @@ void MainFrame::OnRemoveCPinMasks(wxCommandEvent & e)
 void MainFrame::OnPythonScript(wxCommandEvent & e)
 {
     wxString fname;
-    wxFileDialog dlg(wxTheApp->GetTopWindow(),
+    wxFileDialog dlg(wxGetActiveWindow(),
             _("Select python script"),
             wxConfigBase::Get()->Read(wxT("/lensPath"),wxT("")), wxT(""),
             _("Python script (*.py)|*.py|All files (*.*)|*.*"),
@@ -1754,6 +1766,8 @@ void MainFrame::enableTools(bool option)
     theMenuBar->Enable(XRCID("action_finetune_all_cp"), option);
     theMenuBar->Enable(XRCID("action_remove_cp_in_masks"), option);
     theMenuBar->Enable(XRCID("ID_SHOW_PREVIEW_FRAME"), option);
+    theMenuBar->Enable(XRCID("action_stitch"), option);
+    theMenuBar->Enable(XRCID("action_stitch_userdefined"), option);
     //theMenuBar->Enable(XRCID("ID_SHOW_GL_PREVIEW_FRAME"), option);
 }
 
@@ -1776,6 +1790,21 @@ CPDetectorSetting& MainFrame::GetDefaultSetting()
     return images_panel->GetDefaultSetting();
 };
 
+void MainFrame::RunCPGenerator(CPDetectorSetting &setting, const HuginBase::UIntSet& img)
+{
+    images_panel->RunCPGenerator(setting, img);
+};
+
+void MainFrame::RunCPGenerator(const HuginBase::UIntSet& img)
+{
+    images_panel->RunCPGenerator(img);
+};
+
+const wxString MainFrame::GetSelectedCPGenerator()
+{
+    return images_panel->GetSelectedCPGenerator();
+};
+
 const wxString & MainFrame::GetXRCPath()
 {
      return huginApp::Get()->GetXRCPath();
@@ -1838,7 +1867,7 @@ struct celeste::svm_model* MainFrame::GetSVMModel()
         // get XRC path from application
         wxString wxstrModelFileName = huginApp::Get()->GetDataPath() + wxT(HUGIN_CELESTE_MODEL);
         // convert wxString to string
-        string strModelFileName(wxstrModelFileName.mb_str(HUGIN_CONV_FILENAME));
+        std::string strModelFileName(wxstrModelFileName.mb_str(HUGIN_CONV_FILENAME));
 
         // SVM model file
         if (! wxFile::Exists(wxstrModelFileName) ) {
@@ -2074,23 +2103,21 @@ void MainFrame::RunAssistant(wxWindow* mainWin)
 
     //delete temporary files
     wxRemoveFile(scriptFileName.GetFullPath());
-    //if return value is non-zero, an error occured in the assistant
+    //if return value is non-zero, an error occurred in the assistant
     if(ret!=0)
     {
         //check for unconnected images
-        HuginBase::CPGraph graph;
-        HuginBase::createCPGraph(pano, graph);
-        HuginBase::CPComponents comps;
-        int n = HuginBase::findCPComponents(graph, comps);
-        if(n > 1)
+        HuginGraph::ImageGraph graph(pano);
+        const HuginGraph::ImageGraph::Components comps = graph.GetComponents();
+        if(comps.size() > 1)
         {
             // switch to images panel.
             unsigned i1 = *(comps[0].rbegin());
             unsigned i2 = *(comps[1].begin());
             ShowCtrlPointEditor( i1, i2);
             // display message box with 
-            wxMessageBox(wxString::Format(_("Warning %d unconnected image groups found:"), n) + Components2Str(comps) + wxT("\n")
-                + _("Please create control points between unconnected images using the Control Points tab.\n\nAfter adding the points, press the \"Align\" button again"),_("Error"), wxOK , mainWin);
+            wxMessageBox(wxString::Format(_("Warning %d unconnected image groups found:"), comps.size()) + Components2Str(comps) + wxT("\n")
+                + _("Please create control points between unconnected images using the Control Points tab in the panorama editor.\n\nAfter adding the points, press the \"Align\" button again"),_("Error"), wxOK , mainWin);
             return;
         };
         wxMessageBox(_("The assistant did not complete successfully. Please check the resulting project file."),
@@ -2130,7 +2157,7 @@ void MainFrame::OnSendToAssistantQueue(wxCommandEvent &e)
             // error, can't find PTBatcherGUI
             wxMessageBox(wxString::Format(_("External program %s not found in the bundle, reverting to system path"), wxT("open")), _("Error"));
             // Possibly a silly attempt otherwise the previous would have worked as well, but just try it.
-            wxExecute(_T("open -b net.sourceforge.hugin.PTBatcherGUI ")+wxQuoteFilename(projectFile));
+            wxExecute(_T("open -b net.sourceforge.hugin.PTBatcherGUI ")+hugin_utils::wxQuoteFilename(projectFile));
             return;
         }
 
@@ -2168,7 +2195,7 @@ void MainFrame::OnSendToAssistantQueue(wxCommandEvent &e)
         }
 #else
         const wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
-        wxExecute(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("PTBatcherGUI -a ")+wxQuoteFilename(projectFile));
+        wxExecute(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("PTBatcherGUI -a ")+hugin_utils::wxQuoteFilename(projectFile));
 #endif
     }
 };
