@@ -34,6 +34,7 @@
 #include "wx/docview.h"
 #ifdef __WXMSW__
 #include "wx/msw/helpchm.h"
+#include "base_wx/wxPlatform.h"
 #endif
 
 #include <appbase/ProgressDisplay.h>
@@ -56,7 +57,6 @@ class PreviewFrame;
 class GLPreviewFrame;
 class CPListFrame;
 
-
 /** simple class that forward the drop to the mainframe */
 class PanoDropTarget : public wxFileDropTarget
 {
@@ -130,6 +130,7 @@ public:
     void OnOptimize(wxCommandEvent & e);
     void OnPhotometricOptimize(wxCommandEvent & e);
     void OnDoStitch(wxCommandEvent & e);
+    void OnUserDefinedStitch(wxCommandEvent & e);
     void OnTogglePreviewFrame(wxCommandEvent & e);
     void OnToggleGLPreviewFrame(wxCommandEvent & e);
     void OnAddImages(wxCommandEvent & e);
@@ -139,7 +140,7 @@ public:
     void OnSetGuiExpert(wxCommandEvent & e);
 
     /** call help browser with given file */
-    void DisplayHelp(wxString section);
+    void DisplayHelp(wxString section = wxEmptyString);
 
     /** opens the control points tab with the both images selected */
     void ShowCtrlPointEditor(unsigned int img1, unsigned int img2);
@@ -151,6 +152,12 @@ public:
     void OnCPListFrameClosed();
     /** returns default cp detector setting */
     CPDetectorSetting& GetDefaultSetting();
+    /** run the cp generator with the given setting on selected images */
+    void RunCPGenerator(CPDetectorSetting &setting, const HuginBase::UIntSet& img);
+    /** runs the currently selected cp generator on given images */
+    void RunCPGenerator(const HuginBase::UIntSet& img);
+    /** return the currently selected cp generator description */
+    const wxString GetSelectedCPGenerator();
 
     wxString getProjectName();
 
@@ -158,7 +165,7 @@ public:
     
     GLPreviewFrame * getGLPreview();
 #ifdef __WXMSW__
-    wxCHMHelpController& GetHelpController() { return m_msHtmlHelp; }
+    HuginCHMHelpController& GetHelpController() { return m_msHtmlHelp; }
 #endif
     void SetGuiLevel(GuiLevel newLevel);
     const GuiLevel GetGuiLevel() const { return m_guiLevel; };
@@ -259,7 +266,7 @@ private:
     wxMenu* m_menu_file_advanced;
 
 #ifdef __WXMSW__
-    wxCHMHelpController     m_msHtmlHelp;
+    HuginCHMHelpController     m_msHtmlHelp;
 #endif
 
 #ifdef HUGIN_HSI
