@@ -63,9 +63,6 @@ extern "C" {
 
 #define WX_BROKEN_SIZER_UNKNOWN
 
-using namespace std;
-using namespace hugin_utils;
-
 BEGIN_EVENT_TABLE(PanoPanel, wxPanel)
     EVT_CHOICE ( XRCID("pano_choice_pano_type"),PanoPanel::ProjectionChanged )
     EVT_TEXT_ENTER( XRCID("pano_text_hfov"),PanoPanel::HFOVChanged )
@@ -262,7 +259,7 @@ bool PanoPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, cons
     return true;
 }
 
-void PanoPanel::Init(Panorama * panorama)
+void PanoPanel::Init(HuginBase::Panorama * panorama)
 {
     pano = panorama;
     // observe the panorama
@@ -314,9 +311,9 @@ bool PanoPanel::StackCheck(HuginBase::Panorama &pano)
     HuginBase::PanoramaOptions opt = pano.getOptions();
 
     // Determine if there are stacks in the pano.
-    UIntSet activeImages = pano.getActiveImages();
-    UIntSet images = getImagesinROI(pano,activeImages);
-    vector<UIntSet> hdrStacks = HuginBase::getHDRStacks(pano, images, pano.getOptions());
+    HuginBase::UIntSet activeImages = pano.getActiveImages();
+    HuginBase::UIntSet images = getImagesinROI(pano, activeImages);
+    std::vector<HuginBase::UIntSet> hdrStacks = HuginBase::getHDRStacks(pano, images, pano.getOptions());
     DEBUG_DEBUG(hdrStacks.size() << ": HDR stacks detected");
     const bool hasStacks = (hdrStacks.size() != activeImages.size());
 
@@ -360,7 +357,7 @@ bool PanoPanel::StackCheck(HuginBase::Panorama &pano)
 
 void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool hasStacks)
 {
-
+    Freeze();
 //    m_HFOVSpin->SetRange(1,opt.getMaxHFOV());
 //    m_VFOVSpin->SetRange(1,opt.getMaxVFOV());
 
@@ -368,9 +365,9 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     m_keepViewOnResize = opt.fovCalcSupported(opt.getProjection());
 
     std::string val;
-    val = doubleToString(opt.getHFOV(),1);
+    val = hugin_utils::doubleToString(opt.getHFOV(),1);
     m_HFOVText->SetValue(wxString(val.c_str(), wxConvLocal));
-    val = doubleToString(opt.getVFOV(),1);
+    val = hugin_utils::doubleToString(opt.getVFOV(), 1);
     m_VFOVText->SetValue(wxString(val.c_str(), wxConvLocal));
 
     // disable VFOV edit field, due to bugs in setHeight(), setWidth()
@@ -581,11 +578,11 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
 
     m_pano_ctrls->FitInside();
     Layout();
+    Thaw();
 
 #ifdef __WXMSW__
     this->Refresh(false);
 #endif
-
 }
 
 void PanoPanel::ProjectionChanged ( wxCommandEvent & e )
@@ -618,7 +615,7 @@ void PanoPanel::HFOVChanged ( wxCommandEvent & e )
     }
 
     double hfov;
-    if (!str2double(text, hfov)) {
+    if (!hugin_utils::str2double(text, hfov)) {
         wxLogError(_("Value must be numeric."));
         return;
     }
@@ -649,7 +646,7 @@ void PanoPanel::VFOVChanged ( wxCommandEvent & e )
     }
 
     double vfov;
-    if (!str2double(text, vfov)) {
+    if (!hugin_utils::str2double(text, vfov)) {
         wxLogError(_("Value must be numeric."));
         return;
     }
@@ -923,7 +920,7 @@ void PanoPanel::DoCalcFOV(wxCommandEvent & e)
     HuginBase::CalculateFitPanorama fitPano(*pano);
     fitPano.run();
     opt.setHFOV(fitPano.getResultHorizontalFOV());
-    opt.setHeight(roundi(fitPano.getResultHeight()));
+    opt.setHeight(hugin_utils::roundi(fitPano.getResultHeight()));
 
     DEBUG_INFO ( "hfov: " << opt.getHFOV() << "  w: " << opt.getWidth() << " h: " << opt.getHeight() << "  => vfov: " << opt.getVFOV()  << "  before update");
 
@@ -941,7 +938,17 @@ void PanoPanel::DoCalcOptimalWidth(wxCommandEvent & e)
     if (pano->getActiveImages().size() == 0) return;
 
     HuginBase::PanoramaOptions opt = pano->getOptions();
-    unsigned width = hugin_utils::roundi(HuginBase::CalculateOptimalScale::calcOptimalScale(*pano) * opt.getWidth());
+    double sizeFactor = 1.0;
+#if wxCHECK_VERSION(2,9,4)
+    if (wxGetKeyState(WXK_COMMAND))
+#else
+    if (wxGetKeyState(WXK_CONTROL))
+#endif
+    {
+        wxConfigBase::Get()->Read(wxT("/Assistant/panoDownsizeFactor"), &sizeFactor, HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
+    };
+
+    unsigned width = hugin_utils::roundi(HuginBase::CalculateOptimalScale::calcOptimalScale(*pano) * opt.getWidth() * sizeFactor);
 
     if (width > 0) {
         opt.setWidth( width );
@@ -972,10 +979,10 @@ void PanoPanel::DoCalcOptimalROI(wxCommandEvent & e)
         };
     };
 
-    HuginBase::PanoramaOptions opt = pano->getOptions();
     //set the ROI - fail if the right/bottom is zero, meaning all zero
-    if(newROI.right() != 0 && newROI.bottom() != 0)
+    if(!newROI.isEmpty())
     {
+        HuginBase::PanoramaOptions opt = pano->getOptions();
         opt.setROI(newROI);
         PanoCommand::GlobalCmdHist::getInstance().addCommand(
             new PanoCommand::SetPanoOptionsCmd( *pano, opt )
@@ -1013,7 +1020,7 @@ void PanoPanel::DoStitch()
     }
     DEBUG_DEBUG("tmp PTO file: " << (const char *)currentPTOfn.mb_str(wxConvLocal));
     // copy is not enough, need to adjust image path names...
-    ofstream script(currentPTOfn.mb_str(HUGIN_CONV_FILENAME));
+    std::ofstream script(currentPTOfn.mb_str(HUGIN_CONV_FILENAME));
     HuginBase::UIntSet all;
     if (pano->getNrOfImages() > 0) {
         fill_set(all, 0, pano->getNrOfImages()-1);
@@ -1092,7 +1099,7 @@ void PanoPanel::DoStitch()
     wxString switches(wxT(" --delete -o "));
     if(wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) == 1)
         switches=wxT(" --overwrite")+switches;
-    wxString command = hugin_stitch_project + switches + wxQuoteFilename(dlg.GetPath()) + wxT(" ") + wxQuoteFilename(currentPTOfn);
+    wxString command = hugin_stitch_project + switches + hugin_utils::wxQuoteFilename(dlg.GetPath()) + wxT(" ") + hugin_utils::wxQuoteFilename(currentPTOfn);
     
     wxConfigBase::Get()->Flush();
 #ifdef __WXGTK__
@@ -1217,24 +1224,168 @@ void PanoPanel::DoSendToBatch()
 			//We need to call the binary from it's own bundle and not from the hugin bundle otherwise we get no menu as OSX assumes that the hugin bundle
 			//will provide the menu
 			cmd = wxQuoteString(cmd); 
-			cmd += wxT(" ")+switches+wxQuoteFilename(projectFile)+wxT(" ")+wxQuoteFilename(dlg.GetPath());	
+            cmd += wxT(" ")+switches+hugin_utils::wxQuoteFilename(projectFile)+wxT(" ")+hugin_utils::wxQuoteFilename(dlg.GetPath());	
 			wxExecute(cmd);
 		}
 		else
 		{ //Can't find PTBatcherGui.app bundle. Use the most straightforward call possible to the bundle but this should actually not work either.
 				wxMessageBox(wxString::Format(_("External program %s not found in the bundle, reverting to system path"), wxT("open")), _("Error"));
-				cmd = wxT("open -b net.sourceforge.hugin.PTBatcherGUI ")+wxQuoteFilename(projectFile);
+                cmd = wxT("open -b net.sourceforge.hugin.PTBatcherGUI ")+hugin_utils::wxQuoteFilename(projectFile);
 				wxExecute(cmd);
 		}
 		
 #else
         const wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
-        wxExecute(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("PTBatcherGUI ")+switches+wxQuoteFilename(projectFile)+wxT(" ")+wxQuoteFilename(dlg.GetPath()));
+        wxExecute(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("PTBatcherGUI ") + switches + hugin_utils::wxQuoteFilename(projectFile) + wxT(" ") + hugin_utils::wxQuoteFilename(dlg.GetPath()));
 #endif
         HuginBase::LensDB::SaveLensDataFromPano(*pano);
     }
 };
 
+void PanoPanel::DoUserDefinedStitch()
+{
+    if (pano->getNrOfImages() == 0)
+    {
+        return;
+    }
+
+    if (!CheckGoodSize())
+    {
+        // oversized pano and the user no longer wants to stitch.
+        return;
+    }
+    if (!CheckHasImages())
+    {
+        // output ROI contains no images
+        return;
+    };
+    // create a copy, if we need to update the crop setting
+    wxConfigBase* config = wxConfigBase::Get();
+    wxString path = config->Read(wxT("/userDefinedOutputPath"), MainFrame::Get()->GetDataPath());
+    wxFileDialog userOutputDlg(this, _("Select user defined output"),
+        path, wxT(""), _("User defined output|*.executor"),
+        wxFD_OPEN | wxFD_MULTIPLE | wxFD_FILE_MUST_EXIST, wxDefaultPosition);
+    if (userOutputDlg.ShowModal() != wxID_OK)
+    {
+        return;
+    };
+    // remember path for later
+    config->Write(wxT("/userDefinedOutputPath"), userOutputDlg.GetDirectory());
+
+    // save project
+    // copy pto file to temporary file
+    wxString tempDir = wxConfigBase::Get()->Read(wxT("tempDir"), wxT(""));
+    if (!tempDir.IsEmpty())
+    {
+        if (tempDir.Last() != wxFileName::GetPathSeparator())
+        {
+            tempDir.Append(wxFileName::GetPathSeparator());
+        }
+    };
+    wxString currentPTOfn = wxFileName::CreateTempFileName(tempDir + wxT("huginpto_"));
+    if (currentPTOfn.size() == 0)
+    {
+        wxMessageBox(_("Could not create temporary project file"), _("Error"),
+            wxCANCEL | wxICON_ERROR, this);
+        return;
+    }
+    DEBUG_DEBUG("tmp PTO file: " << (const char *)currentPTOfn.mb_str(wxConvLocal));
+    // copy is not enough, need to adjust image path names...
+    std::ofstream script(currentPTOfn.mb_str(HUGIN_CONV_FILENAME));
+    HuginBase::UIntSet all;
+    fill_set(all, 0, pano->getNrOfImages() - 1);
+    pano->printPanoramaScript(script, pano->getOptimizeVector(), pano->getOptions(), all, false, "");
+    script.close();
+
+    //    wxCommandEvent dummy;
+    //    MainFrame::Get()->OnSaveProject(dummy);
+
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+    // HuginStitchProject inside main bundle
+    wxString hugin_stitch_project = MacGetPathToBundledAppMainExecutableFile(CFSTR("HuginStitchProject.app"));
+    if (hugin_stitch_project == wxT(""))
+    {
+        DEBUG_ERROR("hugin_stitch_project could not be found in the bundle.");
+        return;
+    }
+    hugin_stitch_project = wxQuoteFilename(hugin_stitch_project);
+#elif defined __WXMAC__
+    // HuginStitchProject installed in INSTALL_OSX_BUNDLE_DIR
+    wxFileName hugin_stitch_project_app(wxT(INSTALL_OSX_BUNDLE_DIR), wxEmptyString);
+    hugin_stitch_project_app.AppendDir(wxT("HuginStitchProject.app"));
+    CFStringRef stitchProjectAppPath = MacCreateCFStringWithWxString(hugin_stitch_project_app.GetFullPath());
+    wxString hugin_stitch_project = MacGetPathToMainExecutableFileOfBundle(stitchProjectAppPath);
+    CFRelease(stitchProjectAppPath);
+#else
+    wxString hugin_stitch_project = wxT("hugin_stitch_project");
+#endif
+
+    // Derive a default output prefix from the project filename if set, otherwise default project filename
+    wxFileName outputPrefix(getDefaultOutputName(MainFrame::Get()->getProjectName(), *pano));
+    outputPrefix.Normalize();
+
+    // Show a file save dialog so user can confirm/change the prefix.
+    // (We don't have to worry about overwriting existing files, since hugin_switch_project checks this.)
+    // TODO: The following code is similar to stitchApp::OnInit in hugin_switch_project.cpp. Should be refactored.
+    // TODO: We should save the output prefix somewhere, so we can recall it as the default if the user stitches this project again.
+    wxFileDialog dlg(this, _("Specify output prefix"),
+        outputPrefix.GetPath(), outputPrefix.GetName(), wxT(""),
+        wxFD_SAVE, wxDefaultPosition);
+    if (dlg.ShowModal() != wxID_OK)
+    {
+        return;
+    };
+    while (containsInvalidCharacters(dlg.GetPath()))
+    {
+        wxArrayString list;
+        list.Add(dlg.GetPath());
+        ShowFilenameWarning(this, list);
+        if (dlg.ShowModal() != wxID_OK)
+            return;
+    };
+    wxFileName prefix(dlg.GetPath());
+    while (!prefix.IsDirWritable())
+    {
+        wxMessageBox(wxString::Format(_("You have no permissions to write in folder \"%s\".\nPlease select another folder for the final output."), prefix.GetPath().c_str()),
+#ifdef __WXMSW__
+            wxT("Hugin"),
+#else
+            wxT(""),
+#endif
+            wxOK | wxICON_INFORMATION);
+        if (dlg.ShowModal() != wxID_OK)
+        {
+            return;
+        };
+        prefix = dlg.GetPath();
+    };
+    // check free space
+    if (!CheckFreeSpace(prefix.GetPath()))
+    {
+        return;
+    };
+
+    wxString switches(wxT(" --user-defined-output=") + hugin_utils::wxQuoteFilename(userOutputDlg.GetPath()) + wxT(" --delete -o "));
+    if (wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) == 1)
+        switches = wxT(" --overwrite") + switches;
+    wxString command = hugin_stitch_project + switches + hugin_utils::wxQuoteFilename(dlg.GetPath()) + wxT(" ") + hugin_utils::wxQuoteFilename(currentPTOfn);
+
+    wxConfigBase::Get()->Flush();
+#ifdef __WXGTK__
+    // work around a wxExecute bug/problem
+    // (endless polling of fd 0 and 1 in hugin_stitch_project)
+    wxProcess *my_process = new wxProcess(this);
+    my_process->Redirect();
+
+    // Delete itself once processes terminated.
+    my_process->Detach();
+    wxExecute(command, wxEXEC_ASYNC, my_process);
+#else
+    wxExecute(command);
+#endif
+}
+
+
 void PanoPanel::OnDoStitch ( wxCommandEvent & e )
 {
     long t;
@@ -1415,7 +1566,24 @@ void PanoPanel::OnOutputFilesChanged(wxCommandEvent & e)
 
 bool PanoPanel::CheckGoodSize()
 {
-    vigra::Rect2D cropped_region = pano->getOptions().getROI();
+    const HuginBase::PanoramaOptions opts(pano->getOptions());
+    const vigra::Rect2D cropped_region (opts.getROI());    
+    // width and height of jpeg images has to be smaller than 65500 pixel
+    if (opts.outputImageType == "jpg" &&
+        (opts.outputLDRBlended || opts.outputLDRExposureBlended || opts.outputLDRExposureLayersFused) &&
+        (cropped_region.width()>65500 || cropped_region.height()>65500)
+        )
+    {
+        wxMessageBox(
+            wxString::Format(_("The width and height of jpeg images has to be smaller than 65500 pixel. But you have requested a jpeg image with %dx%d pixel.\nThis is not supported by the jpeg file format.\nDecrease the canvas size on the stitch panel or select TIF or PNG as output format."), cropped_region.width(), cropped_region.height()),
+#ifdef _WIN32
+            _("Hugin"),
+#else
+            wxT(""),
+#endif
+            wxICON_EXCLAMATION | wxOK);
+        return false;
+    };
     wxString message;
     unsigned long long int area = ((unsigned long int) cropped_region.width()) * ((unsigned long int) cropped_region.height());
     // Argh, more than half a gigapixel!
@@ -1438,7 +1606,7 @@ bool PanoPanel::CheckGoodSize()
 #if wxCHECK_VERSION(2,9,0)
         wxMessageDialog dialog(this,
                 _("Are you sure you want to stitch such a large panorama?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                 _("Hugin"),
 #else
                 wxT(""),
@@ -1464,7 +1632,7 @@ bool PanoPanel::CheckGoodSize()
         message.Prepend(wxT("\n\n"));
         message=_("Are you sure you want to stitch such a large panorama?")+message;
         wxMessageDialog dialog(this, message,
-#ifdef _WINDOWS
+#ifdef _WIN32
                 _("Hugin"),
 #else
                 wxT(""),
@@ -1495,11 +1663,11 @@ bool PanoPanel::CheckGoodSize()
 
 bool PanoPanel::CheckHasImages()
 {
-    UIntSet images=getImagesinROI(*pano, pano->getActiveImages());
+    HuginBase::UIntSet images=getImagesinROI(*pano, pano->getActiveImages());
     if(images.size()==0)
     {
         wxMessageBox(_("There are no active images in the output region.\nPlease check your settings, so that at least one image is in the output region."),
-#ifdef _WINDOWS
+#ifdef _WIN32
             _("Hugin"),
 #else
             wxT(""),
@@ -1520,7 +1688,7 @@ bool PanoPanel::CheckFreeSpace(const wxString& folder)
 #if wxCHECK_VERSION(2,9,0)
             wxMessageDialog dialog(this,
                 wxString::Format(_("The folder \"%s\" has only %.1f MiB free. This is not enough for stitching the current panorama. Decrease the output size or select another output folder.\nAre you sure that you still want to stitch it?"), folder.c_str(), freeSpace / 1048576.0f),
-#ifdef _WINDOWS
+#ifdef _WIN32
                 _("Hugin"),
 #else
                 wxT(""),
@@ -1530,7 +1698,7 @@ bool PanoPanel::CheckFreeSpace(const wxString& folder)
 #else // replacement for old wxWidgets versions.
             wxMessageDialog dialog(this,
                 wxString::Format(_("The folder \"%s\" has only %.1f MiB free. This is not enough for stitching the current panorama. Decrease the output size or select another output folder.\nAre you sure that you still want to stitch it?"), folder.c_str(), freeSpace / 1048576.0f),
-#ifdef _WINDOWS
+#ifdef _WIN32
                 _("Hugin"),
 #else
                 wxT(""),
