@@ -35,7 +35,7 @@ BEGIN_EVENT_TABLE(Batch, wxFrame)
     EVT_END_PROCESS(-1, Batch::OnProcessTerminate)
 END_EVENT_TABLE()
 
-#if _WINDOWS && defined Hugin_shared
+#if defined _WIN32 && defined Hugin_shared
 DEFINE_LOCAL_EVENT_TYPE(EVT_BATCH_FAILED)
 DEFINE_LOCAL_EVENT_TYPE(EVT_INFORMATION)
 DEFINE_LOCAL_EVENT_TYPE(EVT_UPDATE_PARENT)
@@ -223,7 +223,7 @@ int Batch::ClearBatch()
     if(m_stitchFrames.GetCount()!=0)
     {
         wxMessageDialog message(this, _("Cannot clear batch in progress.\nDo you want to cancel it?"),
-#ifdef _WINDOWS
+#ifdef _WIN32
                                 _("PTBatcherGUI"),
 #else
                                 wxT(""),
@@ -349,17 +349,17 @@ void Batch::ListBatch()
 {
     if(m_projList.GetCount() == 0)
     {
-        cout << "Batch is empty." << endl;
+        std::cout << "Batch is empty." << std::endl;
     }
     else
     {
-        cout << "List of projects in batch:" << endl <<
-             "[ID] [project path] [output filename] [status]" << endl <<
-             "-------------------------------------" << endl;
+        std::cout << "List of projects in batch:" << std::endl <<
+             "[ID] [project path] [output filename] [status]" << std::endl <<
+             "-------------------------------------" << std::endl;
         for(unsigned int i=0; i<m_projList.GetCount(); i++)
         {
-            cout << m_projList.Item(i).id << "  "	<< (const char*)m_projList.Item(i).path.char_str()  << "  " << (const char*)m_projList.Item(i).prefix.char_str()
-                 << "  " << (const char*)m_projList.Item(i).GetStatusText().char_str() << endl;
+            std::cout << m_projList.Item(i).id << "  "	<< (const char*)m_projList.Item(i).path.char_str()  << "  " << (const char*)m_projList.Item(i).prefix.char_str()
+                 << "  " << (const char*)m_projList.Item(i).GetStatusText().char_str() << std::endl;
         }
     }
 }
@@ -478,7 +478,7 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
             if(i<1000)
             {
                 //now save log file
-                if(((RunStitchFrame*)(event.GetEventObject()))->SaveLog(logFile.GetFullPath()))
+                if((static_cast<RunStitchFrame*>(event.GetEventObject()))->SaveLog(logFile.GetFullPath()))
                 {
                     savedLogfile=logFile.GetFullPath();
                 }
@@ -529,6 +529,8 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
                 {
                     wxCommandEvent e(EVT_INFORMATION,wxID_ANY);
                     e.SetString(_("Batch successfully completed."));
+                    // setting int to 1 to indicate we are finished
+                    e.SetInt(1);
                     GetParent()->GetEventHandler()->AddPendingEvent(e);
                 }
                 else
@@ -659,8 +661,8 @@ bool Batch::OnStitch(wxString scriptFile, wxString outname, int id)
         }
         else     // bail
         {
+            wxLogError(_("No project files specified"));
             return false;
-            wxLogError( _("No project files specified"));
         }
     }
 
@@ -769,8 +771,7 @@ void Batch::PauseBatch()
 
 void Batch::RemoveProject(int id)
 {
-    int index;
-    if((index=GetIndex(id)) != -1)
+    if(GetIndex(id) != -1)
     {
         RemoveProjectAtIndex(GetIndex(id));
     }
@@ -972,7 +973,7 @@ void Batch::ShowOutput(bool isVisible)
 
 wxString Batch::GetFailedProjectName(unsigned int i)
 {
-    if(i>=0 && i<m_failedProjects.size())
+    if(i<m_failedProjects.size())
     {
         return m_failedProjects[i].project;
     }
@@ -984,7 +985,7 @@ wxString Batch::GetFailedProjectName(unsigned int i)
 
 wxString Batch::GetFailedProjectLog(unsigned int i)
 {
-    if(i>=0 && i<m_failedProjects.size())
+    if(i<m_failedProjects.size())
     {
         return m_failedProjects[i].logfile;
     }
