@@ -33,6 +33,7 @@
 #include "DirTraverser.h"
 #ifdef __WXMSW__
 #include "wx/msw/helpchm.h"
+#include "base_wx/wxPlatform.h"
 #endif
 #include "BatchTrayIcon.h"
 //#include <wx/app.h>
@@ -72,6 +73,7 @@ public:
     void OnButtonCancel(wxCommandEvent& event);
     void OnButtonChangePrefix(wxCommandEvent& event);
     void OnButtonClear(wxCommandEvent& event);
+    void OnMinimizeTrayMenu(wxCommandEvent& e);
     void OnButtonHelp(wxCommandEvent& event);
     void OnButtonMoveDown(wxCommandEvent& event);
     void OnButtonMoveUp(wxCommandEvent& event);
@@ -151,7 +153,7 @@ public:
 
 #ifdef __WXMSW__
     /** return help controller for open help */
-    wxCHMHelpController& GetHelpController()
+    HuginCHMHelpController& GetHelpController()
     {
         return m_msHtmlHelp;
     }
@@ -171,12 +173,15 @@ private:
     //TO-DO: include a batch or project progress gauge? Test initialization commented out in constructor
     //wxGauge* m_gauge;
 #ifdef __WXMSW__
-    wxCHMHelpController m_msHtmlHelp;
+    HuginCHMHelpController m_msHtmlHelp;
 #else
     wxHtmlHelpController* m_help;
 #endif
     BatchTaskBarIcon* m_tray;
     ProgressStatusBar* m_progStatusBar;
+    wxIcon m_iconNormal;
+    wxIcon m_iconRunning;
+    wxIcon m_iconPaused;
     bool m_startedMinimized;
 
     void OnProcessTerminate(wxProcessEvent& event);
@@ -191,6 +196,8 @@ private:
     void OnBatchInformation(wxCommandEvent& e);
     /** called if the project box needs to be updated, because projects were added or deleted */
     void OnRefillListBox(wxCommandEvent& e);
+    /** create or destroy the tray icon */
+    void UpdateTrayIcon(const bool createTrayIcon);
 
     DECLARE_EVENT_TABLE()
 };
