@@ -44,8 +44,6 @@
 
 namespace HuginBase {
 
-using namespace hugin_utils;
-
 bool PTOptimizer::runAlgorithm()
 {
     PTools::optimize(o_panorama);
@@ -315,98 +313,54 @@ bool RANSACOptimizer::runAlgorithm()
     return true; // let's hope so.
 }
     
-
-int FindStackNumberForImage(const std::vector<UIntSet>& imageGroups, const unsigned int imgNr)
+class AutoOptimiseVisitor :public HuginGraph::BreadthFirstSearchVisitor
 {
-    for (size_t i = 0; i < imageGroups.size(); ++i)
+public:
+    explicit AutoOptimiseVisitor(PanoramaData* pano, const std::set<std::string>& optvec)
+        : m_opt(optvec), m_pano(pano)
+    {};
+    void Visit(const size_t vertex, const HuginBase::UIntSet& visitedNeighbors, const HuginBase::UIntSet& unvisitedNeighbors)
     {
-        if (set_contains(imageGroups[i], imgNr))
+        UIntSet imgs(visitedNeighbors);
+        imgs.insert(vertex);
+
+        if (imgs.size() > 1)
         {
-            return i;
+            // get pano with neighbouring images.
+            PanoramaData* localPano = m_pano->getNewSubset(imgs); // don't forget to delete
+
+            // find number of current image in subset
+            unsigned currImg = 0;
+            unsigned cnt = 0;
+            for (UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); ++it)
+            {
+                if (vertex == *it)
+                {
+                    currImg = cnt;
+                }
+                cnt++;
+            }
+
+            OptimizeVector optvec(imgs.size());
+            optvec[currImg] = m_opt;
+            localPano->setOptimizeVector(optvec);
+            PTools::optimize(*localPano);
+            m_pano->updateVariables(vertex, localPano->getImageVariables(currImg));
+            delete localPano;
         };
     };
-    return -1;
+private:
+    const std::set<std::string>& m_opt;
+    PanoramaData* m_pano;
 };
 
 void AutoOptimise::autoOptimise(PanoramaData& pano, bool optRoll)
 {
-    CPVector cps = pano.getCtrlPoints();
-    CPVector newCP;
-
     // remove all connected images, keep only a single image for each connected stack
-    std::vector<UIntSet> imageGroups;
-    UIntSet visitedImages;
-    PanoramaData* optPano;
-    for (size_t i = 0; i < pano.getNrOfImages(); ++i)
-    {
-        if (set_contains(visitedImages, i))
-        {
-            continue;
-        };
-        const SrcPanoImage& img1 = pano.getImage(i);
-        UIntSet imgs;
-        imgs.insert(i);
-        visitedImages.insert(i);
-        if (img1.YawisLinked() && i + 1 < pano.getNrOfImages())
-        {
-            for (size_t j = i + 1; j < pano.getNrOfImages(); ++j)
-            {
-                if (img1.YawisLinkedWith(pano.getImage(j)))
-                {
-                    imgs.insert(j);
-                    visitedImages.insert(j);
-                }
-            }
-        };
-        imageGroups.push_back(imgs);
-    };
-    UIntSet singleStackImgs;
-    for (size_t i = 0; i < imageGroups.size(); ++i)
-    {
-        singleStackImgs.insert(*imageGroups[i].begin());
-    };
-    // new generate subpano
-    optPano = pano.getNewSubset(singleStackImgs);
-    // translate now reference image
-    int newRefImage = FindStackNumberForImage(imageGroups, pano.getOptions().optimizeReferenceImage);
-    if (newRefImage != -1)
-    {
-        PanoramaOptions opts = optPano->getOptions();
-        opts.optimizeReferenceImage = newRefImage;
-        optPano->setOptions(opts);
-    };
-    // remove all vertical and horizontal cp, also remap all cps to new subpano
-    // all cps from removed images will be mapped to first image of corresponding stack
-    for (CPVector::const_iterator it = cps.begin(); it != cps.end(); ++it)
-    {
-        if (it->mode == ControlPoint::X_Y)
-        {
-            ControlPoint cp (*it);
-            int newImg1 = FindStackNumberForImage(imageGroups, cp.image1Nr);
-            int newImg2 = FindStackNumberForImage(imageGroups, cp.image2Nr);
-            if (newImg1 != -1 && newImg2 != -1 && newImg1 != newImg2)
-            {
-                cp.image1Nr = newImg1;
-                cp.image2Nr = newImg2;
-                newCP.push_back(cp);
-            };
-        };
-    };
-    optPano->setCtrlPoints(newCP);
+    UIntSetVector imageGroups;
+    // don't forget to delete at end
+    PanoramaData* optPano = pano.getUnlinkedSubset(imageGroups);
 
-    // DGSW FIXME - Unreferenced
-    //	unsigned nImg = unsigned(pano.getNrOfImages());
-    // build a graph over all overlapping images
-    CPGraph graph;
-    createCPGraph(*optPano,graph);
-    
-#if DEBUG
-    {
-        std::ofstream gfile("cp_graph.dot");
-        // output doxygen graph
-        boost::write_graphviz(gfile, graph);
-    }
-#endif
     std::set<std::string> optvars;
     if(optRoll)
     {
@@ -415,17 +369,11 @@ void AutoOptimise::autoOptimise(PanoramaData& pano, bool optRoll)
     optvars.insert("p");
     optvars.insert("y");
     
-    unsigned int startImg = optPano->getOptions().optimizeReferenceImage;
-    
     // start a breadth first traversal of the graph, and optimize
     // the links found (every vertex just once.)
-    
-    OptimiseVisitor optVisitor(*optPano, optvars);
-    
-    boost::queue<boost::graph_traits<CPGraph>::vertex_descriptor> qu;
-    boost::breadth_first_search(graph, startImg,
-                                color_map(get(boost::vertex_color, graph)).
-                                visitor(optVisitor));
+    HuginGraph::ImageGraph graph(*optPano);
+    AutoOptimiseVisitor visitor(optPano, optvars);
+    graph.VisitAllImages(optPano->getOptions().optimizeReferenceImage, true, &visitor);
 
     // now translate to found positions to initial pano
     for (size_t i = 0; i < optPano->getNrOfImages(); ++i)
@@ -433,28 +381,6 @@ void AutoOptimise::autoOptimise(PanoramaData& pano, bool optRoll)
         pano.updateVariables(*imageGroups[i].begin(), optPano->getImageVariables(i));
     };
     delete optPano;
-    /*
-#ifdef DEBUG
-     // print optimized script to cout
-     DEBUG_DEBUG("after local optim:");
-     VariableMapVector vars = optVisitor.getVariables();
-     for (unsigned v=0; v < pano.getNrOfImages(); v++) {
-         printVariableMap(std::cerr, vars[v]);
-         std::cerr << std::endl;
-     }
-#endif
-     
-     // apply variables to input panorama
-     pano.updateVariables(optVisitor.getVariables());
-     
-#ifdef DEBUG
-     UIntSet allImg;
-     fill_set(allImg,0, pano.getNrOfImages()-1);
-     // print optimized script to cout
-     DEBUG_DEBUG("after updateVariables():");
-     pano.printPanoramaScript(std::cerr, pano.getOptimizeVector(), pano.getOptions(), allImg, false);
-#endif
-     */
 }
 
 
@@ -552,7 +478,7 @@ void SmartOptimise::smartOptimize(PanoramaData& optPano)
         // check if this is a 360 deg pano.
         CenterHorizontally(optPano).run();
         //FDiff2D fov = CalculateFOV(optPano).run<CalculateFOV>().getResultFOV();
-            FDiff2D fov = CalculateFOV::calcFOV(optPano);
+            hugin_utils::FDiff2D fov = CalculateFOV::calcFOV(optPano);
         
         if (fov.x >= 150) {
             // optimize HFOV for 150 deg panos
