@@ -27,19 +27,24 @@
 #ifndef _NONA_REMAPPEDPANOIMAGE_H
 #define _NONA_REMAPPEDPANOIMAGE_H
 
-#include <vigra/impex.hxx>
+#include <vigra/imageinfo.hxx>
 #include <vigra/initimage.hxx>
 #include <vigra/copyimage.hxx>
 #include <vigra/flatmorphology.hxx>
 #include <vigra_ext/ROIImage.h>
 
 #include <appbase/ProgressDisplay.h>
+#include <nona/StitcherOptions.h>
 
 #include <panodata/SrcPanoImage.h>
 #include <panodata/Mask.h>
 #include <panodata/PanoramaOptions.h>
 #include <panotools/PanoToolsInterface.h>
 
+// default values for exposure cutoff
+#define NONA_DEFAULT_EXPOSURE_LOWER_CUTOFF 1/255.0f
+#define NONA_DEFAULT_EXPOSURE_UPPER_CUTOFF 250/255.0f
+
 
 namespace HuginBase {
 namespace Nona {
@@ -98,7 +103,7 @@ class RemappedPanoImage : public vigra_ext::ROIImage<RemapImage, AlphaImage>
          *
          *  the actual remapping is done by the remapImage() function.
          */
-        RemappedPanoImage()
+        RemappedPanoImage() : m_advancedOptions()
         {};
 
         
@@ -107,25 +112,10 @@ class RemappedPanoImage : public vigra_ext::ROIImage<RemapImage, AlphaImage>
         void setPanoImage(const SrcPanoImage & src,
                           const PanoramaOptions & dest,
                           vigra::Rect2D roi);
-
-    //    /** set a new image or panorama options
-    //     *
-    //     *  This is needed before any of the remap functions can be used.
-    //     *
-    //     *  calculates bounding box, and outline
-    //     */
-    //    void setPanoImage(const vigra::Size2D & srcSize,
-    //                      const PanoCommand::VariableMap & srcVars,
-    //                      PanoCommand::Lens::LensProjectionFormat srcProj,
-    //                      const PanoCommand::PanoImage & img,
-    //                      const vigra::Diff2D &destSize,
-    //                      HuginBase::PanoramaOptions::ProjectionFormat destProj,
-    //                      double destHFOV);
-    //    
-    //    ///
-    //    void setPanoImage(const HuginBase::Panorama & pano, unsigned int imgNr,
-    //                      vigra::Size2D srcSize, const HuginBase::PanoramaOptions & opts);
-        
+        void setAdvancedOptions(const AdvancedOptions& advancedOptions)
+        {
+            m_advancedOptions = advancedOptions;
+        };
 
     public:
         /** calculate distance map. pixels contain distance from image center
@@ -169,6 +159,7 @@ class RemappedPanoImage : public vigra_ext::ROIImage<RemapImage, AlphaImage>
         SrcPanoImage m_srcImg;
         PanoramaOptions m_destImg;
         PTools::Transform m_transf;
+        AdvancedOptions m_advancedOptions;
 
 };
 
@@ -200,12 +191,11 @@ void remapImage(SrcImgType & srcImg,
 #include <vigra_ext/ImageTransforms.h>
 #include <vigra_ext/ImageTransformsGPU.h>
 
-#ifdef DEBUG
-#define DEBUG_REMAP 1
-#endif
+// #define DEBUG_REMAP 1
 
 #ifdef DEBUG_REMAP
-#ifdef WIN32
+#include <vigra/impex.hxx> // for vigra::exportImage()
+#ifdef _WIN32
 #define DEBUG_FILE_PREFIX "C:/temp/"
 #else
 #define DEBUG_FILE_PREFIX "/tmp/"
@@ -474,8 +464,7 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
         invResponse.setHDROutput(true,1.0/pow(2.0,m_destImg.outputExposureValue));
     }
 
-
-    if ((m_srcImg.hasActiveMasks()) || (m_srcImg.getCropMode() != SrcPanoImage::NO_CROP))
+    if ((m_srcImg.hasActiveMasks()) || (m_srcImg.getCropMode() != SrcPanoImage::NO_CROP) || Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposure", false))
     {
         // need to create and additional alpha image for the crop mask...
         // not very efficient during the remapping phase, but works.
@@ -531,6 +520,12 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
         }
         if(m_srcImg.hasActiveMasks())
             vigra_ext::applyMask(vigra::destImageRange(alpha), m_srcImg.getActiveMasks());
+        if (Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposure", false))
+        {
+            const float lowerCutoff = Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposureLowerCutoff", NONA_DEFAULT_EXPOSURE_LOWER_CUTOFF);
+            const float upperCutoff = Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposureUpperCutoff", NONA_DEFAULT_EXPOSURE_UPPER_CUTOFF);
+            vigra_ext::applyExposureClipMask(srcImg, vigra::destImageRange(alpha), lowerCutoff, upperCutoff);
+        };
         if (useGPU) {
             transformImageAlphaGPU(srcImg,
                                    vigra::srcImage(alpha),
@@ -654,7 +649,7 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
         invResponse.setHDROutput(true,1.0/pow(2.0,m_destImg.outputExposureValue));
     }
 
-    if (((m_srcImg.hasActiveMasks()) || (m_srcImg.getCropMode() != SrcPanoImage::NO_CROP))) {
+    if ((m_srcImg.hasActiveMasks()) || (m_srcImg.getCropMode() != SrcPanoImage::NO_CROP) || Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposure", false)) {
         vigra::BImage alpha(srcImgSize);
         vigra::Rect2D cR = m_srcImg.getCropRect();
         switch (m_srcImg.getCropMode()) {
@@ -699,7 +694,12 @@ void RemappedPanoImage<RemapImage,AlphaImage>::remapImage(vigra::triple<ImgIter,
         }
         if(m_srcImg.hasActiveMasks())
             vigra_ext::applyMask(vigra::destImageRange(alpha), m_srcImg.getActiveMasks());
-
+        if (Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposure", false))
+        {
+            const float lowerCutoff = Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposureLowerCutoff", NONA_DEFAULT_EXPOSURE_LOWER_CUTOFF);
+            const float upperCutoff = Nona::GetAdvancedOption(m_advancedOptions, "maskClipExposureUpperCutoff", NONA_DEFAULT_EXPOSURE_UPPER_CUTOFF);
+            vigra_ext::applyExposureClipMask(srcImg, vigra::destImageRange(alpha), lowerCutoff, upperCutoff);
+        };
         if (useGPU) {
             vigra_ext::transformImageAlphaGPU(srcImg,
                                               vigra::srcImage(alpha),
