@@ -19,26 +19,21 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
 #include "SpaceTransform.h"
 
-
-using namespace std;
-using namespace vigra;
-using namespace hugin_utils;
-
-
 namespace HuginBase {
 namespace Nona {
         
 
 /// ctor
-SpaceTransform::SpaceTransform()
+SpaceTransform::SpaceTransform() : m_srcTX(0), m_srcTY(0), m_destTX(0), m_destTY(0)
 {
+
 	m_Initialized = false;
 }
 
@@ -682,7 +677,7 @@ unsigned char radlum( unsigned char srcPixel, int xc, int yc, void *params )
 
 
 // Get smallest positive (non-zero) root of polynomial with degree deg and
-// (n+1) real coefficients p[i]. Return it, or 1000.0 if none exists or error occured
+// (n+1) real coefficients p[i]. Return it, or 1000.0 if none exists or error occurred
 // Changed to only allow degree 3
 #if 0
 double smallestRoot( double *p )
@@ -966,7 +961,7 @@ double estScaleFactorForFullFrame(const SrcPanoImage & src)
 }
 
 
-double estRadialScaleCrop(const vector<double> &coeff, int width, int height)
+double estRadialScaleCrop(const std::vector<double> &coeff, int width, int height)
 {
     double r_test[4];
     double p, r;
@@ -1048,11 +1043,11 @@ double estRadialScaleCrop(const vector<double> &coeff, int width, int height)
 
 
 /** Create a transform stack for radial distortion correction only */
-void SpaceTransform::InitRadialCorrect(const Size2D & sz, const vector<double> & radDist, 
-                                 const FDiff2D & centerShift)
+void SpaceTransform::InitRadialCorrect(const vigra::Size2D & sz, const std::vector<double> & radDist, 
+                                 const hugin_utils::FDiff2D & centerShift)
 {
     double mprad[6];
-
+    
 //    double  imwidth = src.getSize().x;
 //    double  imheight= src.getSize().y;
 
@@ -1202,11 +1197,11 @@ void SpaceTransform::InitRadialCorrect(const SrcPanoImage & src, int channel)
   */
 void SpaceTransform::Init(
     const SrcPanoImage & image,
-    const Diff2D &destSize,
+    const vigra::Diff2D &destSize,
     PanoramaOptions::ProjectionFormat destProj,
     double destHFOV )
 {
-    int 	i;
+    //int 	i;
     double	a, b;
     Matrix3 mpmt;
     double  mpdistance, mpscale[2], mpshear[2], mprot[2], mprad[6];
@@ -1300,7 +1295,7 @@ void SpaceTransform::Init(
 	//mp->horizontal 	= im->cP.horizontal_params[color];
 	//mp->vertical 	= im->cP.vertical_params[color];
 	
-    i = 0;
+    //i = 0;
 
     switch (destProj)
     {
@@ -1413,7 +1408,7 @@ void SpaceTransform::Init(
 
 void SpaceTransform::InitInv(
     const SrcPanoImage & image,
-    const Diff2D &destSize,
+    const vigra::Diff2D &destSize,
     PanoramaOptions::ProjectionFormat destProj,
     double destHFOV )
 {
@@ -1695,10 +1690,10 @@ void SpaceTransform::createInvTransform(const vigra::Diff2D & srcSize,
 
 
 //
-bool SpaceTransform::transform(FDiff2D& dest, const FDiff2D & src) const
+bool SpaceTransform::transform(hugin_utils::FDiff2D& dest, const hugin_utils::FDiff2D & src) const
 {
 	double xd = src.x, yd = src.y;
-	vector<fDescription>::const_iterator tI;
+	std::vector<fDescription>::const_iterator tI;
 	
     dest.x = xd;
     dest.y = yd;
@@ -1714,7 +1709,7 @@ bool SpaceTransform::transform(FDiff2D& dest, const FDiff2D & src) const
 //
 bool SpaceTransform::transformImgCoord(double & x_dest, double & y_dest, double x_src, double y_src) const
 {
-	FDiff2D dest, src;
+    hugin_utils::FDiff2D dest, src;
 	src.x = x_src - m_srcTX + 0.5;
 	src.y = y_src - m_srcTY + 0.5;
 	transform( dest, src );
