@@ -88,6 +88,8 @@ class IMPEX PanoramaMemento : public PanoramaDataMemento
          * when necessary.
          */
         std::vector<SrcPanoImage *> images;
+        /** description of the icc profile */
+        std::string iccProfileDesc;
         
         CPVector ctrlPoints;
         
@@ -186,7 +188,12 @@ class IMPEX Panorama : public ManagedPanoramaData, public AppBase::DocumentData
              return new Panorama(this->duplicate());
          }
         
-        
+        /** get a panorama, which does not contain
+        *   images linked with positions, the cps are moved to the first image
+        *   of each linked stacked
+        *  @param imageGroups contains a mapping of the initial images to the new images */
+        PanoramaData* getUnlinkedSubset(UIntSetVector& imageGroups) const;
+
     // -- Data Access --
         
     // = images =    
@@ -360,7 +367,11 @@ class IMPEX Panorama : public ManagedPanoramaData, public AppBase::DocumentData
             */
         void updateCtrlPointErrors(const UIntSet & imgs, const CPVector & cps);
         
-        
+        /** return description of icc profile used for pano */
+        const std::string getICCProfileDesc() const;
+        /** sets the icc profile description for check of same profile */
+        void setICCProfileDesc(const std::string& newDesc);
+
     // = Variables =    
         
         /// get variables of this panorama
@@ -577,7 +588,7 @@ class IMPEX Panorama : public ManagedPanoramaData, public AppBase::DocumentData
         void updateMasks(bool convertPosMaskToNeg=false);
         /** transfers given mask from image imgNr to all targetImgs
          */
-        void transferMask(MaskPolygon mask,unsigned int imgNr, const UIntSet targetImgs);
+        void transferMask(MaskPolygon mask,unsigned int imgNr, const UIntSet& targetImgs);
         /** updates the optimize vector according to master switches */
         void updateOptimizeVector();
         /** returns set of reference image and images linked with reference images */
