@@ -28,13 +28,18 @@
 #define PARSEEXP_H
 #include <map>
 #include <string>
+#include "hugin_config.h"
 
 namespace Parser
 {
+#ifdef HAVE_CXX11
+typedef std::map<std::string, double> ConstantMap;
+#else
 typedef std::map<const char*, double> ConstantMap;
+#endif
 
-bool ParseExpression(const std::string& expression, double& result, const ConstantMap& constants=ConstantMap());
-
+bool ParseExpression(const std::string& expression, double& result, const ConstantMap& constants = ConstantMap());
+void CleanUpParser();
 };
 
 #endif
\ No newline at end of file
